@@ -18,6 +18,7 @@
 
 #include "filesystembase.h"
 #include "utility.h"
+#include "common/asserts.h"
 
 #include <QDateTime>
 #include <QDir>
@@ -133,10 +134,13 @@ bool FileSystem::rename(const QString &originFileName,
     bool success = false;
     QString error;
 #ifdef Q_OS_WIN
-    QString orig = longWinPath(originFileName);
-    QString dest = longWinPath(destinationFileName);
-
-    if (isLnkFile(originFileName) || isLnkFile(destinationFileName)) {
+    const QString orig = longWinPath(originFileName);
+    const QString dest = longWinPath(destinationFileName);
+    if (FileSystem::isFileLocked(dest, FileSystem::LockMode::Exclusive)) {
+        error = QCoreApplication::translate("FileSystem", "Can't rename %1, the file is currently in use").arg(destinationFileName);
+    } else if (FileSystem::isFileLocked(orig, FileSystem::LockMode::Exclusive)) {
+        error = QCoreApplication::translate("FileSystem", "Can't rename %1, the file is currently in use").arg(originFileName);
+    } else if (isLnkFile(originFileName) || isLnkFile(destinationFileName)) {
         success = MoveFileEx((wchar_t *)orig.utf16(),
             (wchar_t *)dest.utf16(),
             MOVEFILE_COPY_ALLOWED | MOVEFILE_WRITE_THROUGH);
@@ -168,6 +172,7 @@ bool FileSystem::uncheckedRenameReplace(const QString &originFileName,
     const QString &destinationFileName,
     QString *errorString)
 {
+    Q_ASSERT(errorString);
 #ifndef Q_OS_WIN
     bool success;
     QFile orig(originFileName);
@@ -195,13 +200,20 @@ bool FileSystem::uncheckedRenameReplace(const QString &originFileName,
     if (!QFileInfo(destinationFileName).isWritable()) {
         setFileReadOnly(destinationFileName, false);
     }
-
-    BOOL ok;
-    QString orig = longWinPath(originFileName);
-    QString dest = longWinPath(destinationFileName);
-
-    ok = MoveFileEx((wchar_t *)orig.utf16(),
-        (wchar_t *)dest.utf16(),
+    const QString orig = longWinPath(originFileName);
+    const QString dest = longWinPath(destinationFileName);
+    if (FileSystem::isFileLocked(dest, FileSystem::LockMode::Exclusive)) {
+        *errorString = QCoreApplication::translate("FileSystem", "Can't rename %1, the file is currently in use").arg(destinationFileName);
+        qCWarning(lcFileSystem) << "Renaming failed: " << *errorString;
+        return false;
+    }
+    if (FileSystem::isFileLocked(orig, FileSystem::LockMode::Exclusive)) {
+        *errorString = QCoreApplication::translate("FileSystem", "Can't rename %1, the file is currently in use").arg(originFileName);
+        qCWarning(lcFileSystem) << "Renaming failed: " << *errorString;
+        return false;
+    }
+    const BOOL ok = MoveFileEx(reinterpret_cast<const wchar_t *>(orig.utf16()),
+        reinterpret_cast<const wchar_t *>(dest.utf16()),
         MOVEFILE_REPLACE_EXISTING + MOVEFILE_COPY_ALLOWED + MOVEFILE_WRITE_THROUGH);
     if (!ok) {
         *errorString = Utility::formatWinError(GetLastError());
@@ -366,6 +378,7 @@ bool FileSystem::remove(const QString &fileName, QString *errorString)
 
 bool FileSystem::moveToTrash(const QString &fileName, QString *errorString)
 {
+    // TODO: Qt 5.15 bool QFile::moveToTrash()
 #if defined Q_OS_UNIX && !defined Q_OS_MAC
     QString trashPath, trashFilePath, trashInfoPath;
     QString xdgDataHome = QFile::decodeName(qgetenv("XDG_DATA_HOME"));
@@ -438,29 +451,36 @@ bool FileSystem::moveToTrash(const QString &fileName, QString *errorString)
 #endif
 }
 
-bool FileSystem::isFileLocked(const QString &fileName)
+bool FileSystem::isFileLocked(const QString &fileName, LockMode mode)
 {
 #ifdef Q_OS_WIN
     // Check if file exists
     const QString fName = longWinPath(fileName);
+    auto accessMode = mode == LockMode::Exclusive ? 0 : FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE;
     DWORD attr = GetFileAttributesW(reinterpret_cast<const wchar_t *>(fName.utf16()));
     if (attr != INVALID_FILE_ATTRIBUTES) {
         // Try to open the file with as much access as possible..
         HANDLE win_h = CreateFileW(
             reinterpret_cast<const wchar_t *>(fName.utf16()),
             GENERIC_READ | GENERIC_WRITE,
-            FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
+            accessMode,
             NULL, OPEN_EXISTING,
             FILE_ATTRIBUTE_NORMAL | FILE_FLAG_BACKUP_SEMANTICS,
             NULL);
 
         if (win_h == INVALID_HANDLE_VALUE) {
-            /* could not be opened, so locked? */
-            /* 32 == ERROR_SHARING_VIOLATION */
-            return true;
+            if (GetLastError() == ERROR_SHARING_VIOLATION) {
+                return true;
+            }
+            return false;
         } else {
             CloseHandle(win_h);
         }
+    } else {
+        const auto error = GetLastError();
+        if (error != ERROR_FILE_NOT_FOUND && error != ERROR_PATH_NOT_FOUND) {
+            qCWarning(lcFileSystem()) << "GetFileAttributesW" << Utility::formatWinError(error);
+        }
     }
 #else
     Q_UNUSED(fileName);
@@ -491,33 +511,38 @@ bool FileSystem::isJunction(const QString &filename)
 #endif
 }
 
-QString FileSystem::pathtoUNC(const QString &str)
+#ifdef Q_OS_WIN
+QString FileSystem::pathtoUNC(const QString &_str)
 {
-    int len = 0;
-    QString longStr;
-
-    len = str.length();
-    longStr.reserve(len + 4);
-
-    // prepend \\?\ and convert '/' => '\' to support long names
-    if (str[0] == QLatin1Char('/') || str[0] == QLatin1Char('\\')) {
-        // Don't prepend if already UNC
-        if (!(len > 1 && (str[1] == QLatin1Char('/') || str[1] == QLatin1Char('\\')))) {
-            longStr.append(QStringLiteral("\\\\?"));
-        }
-    } else {
-        longStr.append(QStringLiteral("\\\\?\\")); // prepend string by this four magic chars.
+    Q_ASSERT(QFileInfo(_str).isAbsolute());
+    if (_str.isEmpty()) {
+        return _str;
     }
-    longStr += str;
+    const QString str = QDir::toNativeSeparators(_str);
+    const QLatin1Char sep('\\');
 
-    /* replace all occurences of / with the windows native \ */
-
-    for (auto it = longStr.begin(); it != longStr.end(); ++it) {
-        if (*it == QLatin1Char('/')) {
-            *it = QLatin1Char('\\');
-        }
+    // we already have a unc path
+    if (str.startsWith(sep + sep)) {
+        return str;
     }
-    return longStr;
+    // prepend \\?\ and to support long names
+
+    if (str.at(0) == sep) {
+        // should not happen as we require the path to be absolute
+        return QStringLiteral("\\\\?") + str;
+    }
+    return QStringLiteral("\\\\?\\") + str;
 }
+#endif
 
+bool FileSystem::isChildPathOf(const QString &child, const QString &parent)
+{
+    // if it is a relative path assume a local file, resolve it based on root
+    const auto sensitivity = Utility::fsCaseSensitivity();
+    return (child.startsWith(parent.endsWith(QLatin1Char('/')) ? parent : parent + QLatin1Char('/'), sensitivity)
+        // clear trailing slashes etc
+        || QString::compare(QDir::cleanPath(parent), QDir::cleanPath(child), sensitivity) == 0);
+}
 } // namespace OCC
+
+#include "moc_filesystembase.cpp"
