@@ -180,6 +180,8 @@ QByteArray Utility::userAgentString()
     return QStringLiteral("Mozilla/5.0 (%1) mirall/%2 (%3, %4-%5 ClientArchitecture: %6 OsArchitecture: %7)")
         .arg(platform(),
             QStringLiteral(MIRALL_VERSION_STRING),
+            // accessing the theme to fetch the string is rather difficult
+            // since this is only needed server-side to identify clients, the app name (as of 2.9, the short name) is good enough
             qApp->applicationName(),
             QSysInfo::productType(),
             QSysInfo::kernelVersion(),
@@ -263,10 +265,12 @@ void Utility::usleep(int usec)
 }
 
 // This can be overriden from the tests
-OCSYNC_EXPORT bool fsCasePreserving_override = []()-> bool {
-    QByteArray env = qgetenv("OWNCLOUD_TEST_CASE_PRESERVING");
-    if (!env.isEmpty())
-        return env.toInt();
+OCSYNC_EXPORT bool fsCasePreserving_override = []() -> bool {
+    static bool ok = false;
+    static int env = qEnvironmentVariableIntValue("OWNCLOUD_TEST_CASE_PRESERVING", &ok);
+    if (ok) {
+        return env;
+    }
     return Utility::isWindows() || Utility::isMac();
 }();
 
@@ -578,29 +582,9 @@ QString Utility::makeConflictFileName(
     return conflictFileName;
 }
 
-bool Utility::isConflictFile(const char *name)
+bool Utility::isConflictFile(const QStringRef &name)
 {
-    const char *bname = std::strrchr(name, '/');
-    if (bname) {
-        bname += 1;
-    } else {
-        bname = name;
-    }
-
-    // Old pattern
-    if (std::strstr(bname, "_conflict-"))
-        return true;
-
-    // New pattern
-    if (std::strstr(bname, "(conflicted copy"))
-        return true;
-
-    return false;
-}
-
-bool Utility::isConflictFile(const QString &name)
-{
-    auto bname = name.midRef(name.lastIndexOf(QLatin1Char('/')) + 1);
+    auto bname = name.mid(name.lastIndexOf(QLatin1Char('/')) + 1);
 
     if (bname.contains(QStringLiteral("_conflict-")))
         return true;
