@@ -63,13 +63,13 @@ Optional<Vfs::Mode> Vfs::modeFromString(const QString &str)
     return {};
 }
 
-Result<bool, QString> Vfs::checkAvailability(const QString &path)
+Result<void, QString> Vfs::checkAvailability(const QString &path)
 {
-    const auto mode = bestAvailableVfsMode();
 #ifdef Q_OS_WIN
+    const auto mode = bestAvailableVfsMode();
     if (mode == Mode::WindowsCfApi) {
         const auto info = QFileInfo(path);
-        if (QDir(info.canonicalPath()).isRoot()) {
+        if (QDir(info.canonicalFilePath()).isRoot()) {
             return tr("The Virtual filesystem feature does not support a drive as sync root");
         }
         const auto fs = FileSystem::fileSystemForPath(info.absoluteFilePath());
@@ -84,7 +84,7 @@ Result<bool, QString> Vfs::checkAvailability(const QString &path)
 #else
     Q_UNUSED(path);
 #endif
-    return true;
+    return {};
 }
 
 void Vfs::start(const VfsSetupParams &params)
