@@ -35,6 +35,7 @@
 #include "filesystem.h"
 #include "wizard/owncloudwizard.h"
 #include "guiutility.h"
+#include "settingsdialog.h"
 
 #include <math.h>
 
@@ -263,7 +264,7 @@ void AccountSettings::slotCustomContextMenuRequested(const QPoint &pos)
         QString path = info->_folder->remotePathTrailingSlash();
         path += info->_path;
         connect(ac, &QAction::triggered, this, [this, path]{
-            fetchPrivateLinkUrl(_accountState->account(), path, {}, this, [](const QString &url) {
+            fetchPrivateLinkUrl(_accountState->account(), path, this, [](const QString &url) {
                 Utility::openBrowser(url, nullptr);
             });
         });
@@ -338,7 +339,7 @@ void AccountSettings::slotCustomContextMenuRequested(const QPoint &pos)
     }
 
     if (Theme::instance()->showVirtualFilesOption()
-        && !folder->virtualFilesEnabled() && Vfs::checkAvailability(folder->path())) {
+        && !folder->virtualFilesEnabled() && FolderMan::instance()->checkVfsAvailability(folder->path())) {
         const auto mode = bestAvailableVfsMode();
         if (mode == Vfs::WindowsCfApi || Theme::instance()->enableExperimentalFeatures()) {
             ac = menu->addAction(tr("Enable virtual file support%1...").arg(mode == Vfs::WindowsCfApi ? QString() : tr(" (experimental)")));
@@ -494,7 +495,7 @@ void AccountSettings::slotRemoveCurrentFolder()
                "<p><b>Note:</b> This will <b>not</b> delete any files.</p>")
                 .arg(shortGuiLocalPath),
             QMessageBox::NoButton,
-            this);
+            ocApp()->gui()->settingsDialog());
         messageBox->setAttribute(Qt::WA_DeleteOnClose);
         QPushButton *yesButton =
             messageBox->addButton(tr("Remove Folder Sync Connection"), QMessageBox::YesRole);
@@ -822,7 +823,7 @@ void AccountSettings::slotAccountStateChanged()
         QUrl safeUrl(account->url());
         safeUrl.setPassword(QString()); // Remove the password from the URL to avoid showing it in the UI
         FolderMan *folderMan = FolderMan::instance();
-        for (Folder *folder : folderMan->map().values()) {
+        for (Folder *folder : folderMan->map()) {
             _model->slotUpdateFolderState(folder);
         }
 
@@ -960,13 +961,13 @@ void AccountSettings::refreshSelectiveSyncStatus()
 {
     QString msg;
     int cnt = 0;
-    for (Folder *folder : FolderMan::instance()->map().values()) {
+    for (Folder *folder : FolderMan::instance()->map()) {
         if (folder->accountState() != _accountState) {
             continue;
         }
 
         bool ok;
-        const auto undecidedList = folder->journalDb()->getSelectiveSyncList(SyncJournalDb::SelectiveSyncUndecidedList, &ok);
+        const auto &undecidedList = folder->journalDb()->getSelectiveSyncList(SyncJournalDb::SelectiveSyncUndecidedList, &ok);
         for (const auto &it : undecidedList) {
             // FIXME: add the folder alias in a hoover hint.
             // folder->alias() + QLatin1String("/")
