@@ -42,6 +42,7 @@
 #include "csync_exclude.h"
 #include "common/vfs.h"
 #include "settingsdialog.h"
+#include "translations.h"
 
 #include "config.h"
 
@@ -65,49 +66,79 @@
 
 class QSocket;
 
-namespace OCC {
-
-Q_LOGGING_CATEGORY(lcApplication, "gui.application", QtInfoMsg)
-
 namespace {
 
-    const QString optionsC()
-    {
-        return QStringLiteral(
-        "Options:\n"
-        "  -h --help            : show this help screen.\n"
-        "  -s --showsettings    : show the settings dialog while starting.\n"
-        "  -q --quit            : quit the running instance\n"
-        "  --logfile <filename> : write log output to file <filename>.\n"
-        "  --logfile -          : write log output to stdout.\n"
-        "  --logdir <name>      : write each sync log output in a new file\n"
-        "                         in folder <name>.\n"
-        "  --logexpire <hours>  : removes logs older than <hours> hours.\n"
-        "                         (to be used with --logdir)\n"
-        "  --logflush           : flush the log file after every write.\n"
-        "  --logdebug           : also output debug-level messages in the log.\n"
-        "  --confdir <dirname>  : Use the given configuration folder.");
-    }
+void migrateConfigFile(const QCoreApplication *app)
+{
+    using namespace OCC;
 
-    QString applicationTrPath()
-    {
-        QString devTrPath = qApp->applicationDirPath() + QString::fromLatin1("/../src/gui/");
-        if (QDir(devTrPath).exists()) {
-            // might miss Qt, QtKeyChain, etc.
-            qCWarning(lcApplication) << "Running from build location! Translations may be incomplete!";
-            return devTrPath;
+    if (!ConfigFile::exists()) {
+        // check whether an old config location must be migrated
+        // we support multiple locations from old versions
+        // these are worked on in-order to upgrade from version to version
+        // the algorithm is the same for all these locations, thus we can use a loop
+        QStringList configLocationsToMigrate;
+
+        {
+            // note: this change is temporary to allow using QDesktopServices etc. to determine the paths
+            // the application name was changed to
+            auto scopeGuard = qScopeGuard([&app, oldApplicationName = app->applicationName()] {
+                // reset to original value
+                app->setApplicationName(oldApplicationName);
+            });
+
+            QCoreApplication::setApplicationName(Theme::instance()->appNameGUI());
+
+            // location used in versions <= 2.4
+            // We need to use the deprecated QDesktopServices::storageLocation because of its Qt4 behavior of adding "data" to the path
+            configLocationsToMigrate.append(QDesktopServices::storageLocation(QDesktopServices::DataLocation));
+
+            // location used in versions from 2.5 to 2.8
+            configLocationsToMigrate.append(QStandardPaths::writableLocation(Utility::isWindows() ? QStandardPaths::AppDataLocation : QStandardPaths::AppConfigLocation));
         }
-#if defined(Q_OS_WIN)
-        return QApplication::applicationDirPath();
-#elif defined(Q_OS_MAC)
-        return QApplication::applicationDirPath() + QLatin1String("/../Resources/Translations"); // path defaults to app dir.
-#elif defined(Q_OS_UNIX)
-        return QString::fromLatin1(SHAREDIR "/" APPLICATION_EXECUTABLE "/i18n/");
+
+
+        for (auto oldDir : configLocationsToMigrate) {
+            if (oldDir.endsWith('/')) {
+                // macOS 10.11.x does not like trailing slash for rename/move.
+                oldDir.chop(1);
+            }
+
+            if (QFileInfo(oldDir).isDir()) {
+                auto confDir = ConfigFile::configPath();
+                if (confDir.endsWith('/'))
+                    confDir.chop(1); // macOS 10.11.x does not like trailing slash for rename/move.
+                qCInfo(lcApplication) << "Migrating old config from" << oldDir << "to" << confDir;
+
+                if (!QFile::rename(oldDir, confDir)) {
+                    qCWarning(lcApplication) << "Failed to move the old config directory to its new location (" << oldDir << "to" << confDir << ")";
+
+                    // Try to move the files one by one
+                    if (QFileInfo(confDir).isDir() || QDir().mkpath(confDir)) {
+                        const auto filesList = QDir(oldDir).entryInfoList(QDir::Files);
+                        qCInfo(lcApplication) << "Will move the individual files" << filesList;
+                        for (const auto &fileInfo : filesList) {
+                            if (!QFile::rename(fileInfo.canonicalFilePath(), confDir + "/" + fileInfo.fileName())) {
+                                qCWarning(lcApplication) << "Fallback move of " << fileInfo.fileName() << "also failed";
+                            }
+                        }
+                    }
+                } else {
+#ifndef Q_OS_WIN
+                    // Create a symbolic link so a downgrade of the client would still find the config.
+                    QFile::link(confDir, oldDir);
 #endif
+                }
+            }
+        }
     }
 }
 
-// ----------------------------------------------------------------------------------
+} // namespace
+
+namespace OCC {
+
+Q_LOGGING_CATEGORY(lcApplication, "gui.application", QtInfoMsg)
 
 bool Application::configVersionMigration()
 {
@@ -153,7 +184,7 @@ bool Application::configVersionMigration()
 
         box.exec();
         if (box.clickedButton() != continueBtn) {
-            QTimer::singleShot(0, qApp, SLOT(quit()));
+            QTimer::singleShot(0, qApp, &QApplication::quit);
             return false;
         }
 
@@ -161,7 +192,7 @@ bool Application::configVersionMigration()
         settings->endGroup();
 
         // Wipe confusing keys from the future, ignore the others
-        for (const auto &badKey : deleteKeys)
+        for (const auto &badKey : qAsConst(deleteKeys))
             settings->remove(badKey);
     }
 
@@ -169,6 +200,11 @@ bool Application::configVersionMigration()
     return true;
 }
 
+QString Application::displayLanguage() const
+{
+    return _displayLanguage;
+}
+
 ownCloudGui *Application::gui() const
 {
     return _gui;
@@ -178,19 +214,12 @@ Application::Application(int &argc, char **argv)
     : SharedTools::QtSingleApplication(Theme::instance()->appName(), argc, argv)
     , _gui(nullptr)
     , _theme(Theme::instance())
-    , _helpOnly(false)
-    , _versionOnly(false)
-    , _showLogWindow(false)
     , _logExpire(0)
     , _logFlush(false)
     , _logDebug(false)
     , _userTriggeredConnect(false)
     , _debugMode(false)
 {
-#ifdef Q_OS_LINUX
-    _startedAt.start();
-#endif
-
     qsrand(std::random_device()());
 
 #ifdef Q_OS_WIN
@@ -205,40 +234,11 @@ Application::Application(int &argc, char **argv)
     setApplicationName(_theme->appName());
     setWindowIcon(_theme->applicationIcon());
 
-    if (!ConfigFile().exists()) {
-        // Migrate from version <= 2.4
-        setApplicationName(_theme->appNameGUI());
-        // We need to use the deprecated QDesktopServices::storageLocation because of its Qt4
-        // behavior of adding "data" to the path
-        QString oldDir = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-        if (oldDir.endsWith('/')) oldDir.chop(1); // macOS 10.11.x does not like trailing slash for rename/move.
-        setApplicationName(_theme->appName());
-        if (QFileInfo(oldDir).isDir()) {
-            auto confDir = ConfigFile().configPath();
-            if (confDir.endsWith('/')) confDir.chop(1);  // macOS 10.11.x does not like trailing slash for rename/move.
-            qCInfo(lcApplication) << "Migrating old config from" << oldDir << "to" << confDir;
+    // migrate old configuration files if necessary
+    migrateConfigFile(this);
 
-            if (!QFile::rename(oldDir, confDir)) {
-                qCWarning(lcApplication) << "Failed to move the old config directory to its new location (" << oldDir << "to" << confDir << ")";
-
-                // Try to move the files one by one
-                if (QFileInfo(confDir).isDir() || QDir().mkdir(confDir)) {
-                    const QStringList filesList = QDir(oldDir).entryList(QDir::Files);
-                    qCInfo(lcApplication) << "Will move the individual files" << filesList;
-                    for (const auto &name : filesList) {
-                        if (!QFile::rename(oldDir + "/" + name,  confDir + "/" + name)) {
-                            qCWarning(lcApplication) << "Fallback move of " << name << "also failed";
-                        }
-                    }
-                }
-            } else {
-#ifndef Q_OS_WIN
-                // Create a symbolic link so a downgrade of the client would still find the config.
-                QFile::link(confDir, oldDir);
-#endif
-            }
-        }
-    }
+    // needed during commandline options parsing
+    setApplicationVersion(_theme->versionSwitchOutput());
 
     parseOptions(arguments());
 
@@ -284,10 +284,6 @@ Application::Application(int &argc, char **argv)
     if (isVfsPluginAvailable(Vfs::WithSuffix))
         qCInfo(lcApplication) << "VFS suffix plugin is available";
 
-    //no need to waste time;
-    if (_helpOnly || _versionOnly)
-        return;
-
     if (_quitInstance) {
         QTimer::singleShot(0, qApp, &QApplication::quit);
         return;
@@ -309,9 +305,9 @@ Application::Application(int &argc, char **argv)
                 tr("Error accessing the configuration file"),
                 tr("There was an error while accessing the configuration "
                    "file at %1.")
-                    .arg(ConfigFile().configFile()),
-                tr("Quit ownCloud"));
-            QTimer::singleShot(0, qApp, SLOT(quit()));
+                    .arg(ConfigFile::configFile()),
+                tr("Quit %1").arg(Theme::instance()->appNameGUI()));
+            QTimer::singleShot(0, qApp, &QApplication::quit);
             return;
         }
     }
@@ -326,9 +322,6 @@ Application::Application(int &argc, char **argv)
     // Setting up the gui class will allow tray notifications for the
     // setup that follows, like folder setup
     _gui = new ownCloudGui(this);
-    if (_showLogWindow) {
-        _gui->slotToggleLogBrowser(); // _showLogWindow is set in parseOptions.
-    }
     if (_showSettings) {
         _gui->slotShowSettings();
     }
@@ -343,7 +336,7 @@ Application::Application(int &argc, char **argv)
         this, &Application::slotAccountStateAdded);
     connect(AccountManager::instance(), &AccountManager::accountRemoved,
         this, &Application::slotAccountStateRemoved);
-    foreach (auto ai, AccountManager::instance()->accounts()) {
+    for (const auto &ai : AccountManager::instance()->accounts()) {
         slotAccountStateAdded(ai.data());
     }
 
@@ -444,8 +437,8 @@ void Application::slotSystemOnlineConfigurationChanged(QNetworkConfiguration cnf
 
 void Application::slotCheckConnection()
 {
-    auto list = AccountManager::instance()->accounts();
-    foreach (const auto &accountState, list) {
+    const auto &list = AccountManager::instance()->accounts();
+    for (const auto &accountState : list) {
         AccountState::State state = accountState->state();
 
         // Don't check if we're manually signed out or
@@ -481,6 +474,11 @@ void Application::slotCrashFatal()
     qFatal("la Qt fatale");
 }
 
+void Application::slotShowGuiMessage(const QString &title, const QString &message)
+{
+    gui()->slotShowGuiMessage(title, message);
+}
+
 
 void Application::slotownCloudWizardDone(int res)
 {
@@ -524,7 +522,10 @@ void Application::setupLogging()
     // Possibly configure logging from config file
     LogBrowser::setupLoggingFromConfig();
 
-    qCInfo(lcApplication) << QString::fromLatin1("################## %1 locale:[%2] ui_lang:[%3] version:[%4] os:[%5]").arg(_theme->appName()).arg(QLocale::system().name()).arg(property("ui_lang").toString()).arg(_theme->version()).arg(Utility::platformName());
+    qCInfo(lcApplication) << "##################" << _theme->appName()
+                          << "locale:" << QLocale::system().name()
+                          << "version:" << _theme->aboutVersions(Theme::VersionFormat::OneLiner);
+    qCInfo(lcApplication) << "Arguments:" << qApp->arguments();
 }
 
 void Application::slotUseMonoIconsChanged(bool)
@@ -537,143 +538,132 @@ void Application::slotParseMessage(const QString &msg, QObject *)
     if (msg.startsWith(QLatin1String("MSG_PARSEOPTIONS:"))) {
         const int lengthOfMsgPrefix = 17;
         QStringList options = msg.mid(lengthOfMsgPrefix).split(QLatin1Char('|'));
-        _showLogWindow = false;
         _showSettings = false;
         parseOptions(options);
         setupLogging();
-        if (_showLogWindow) {
-            _gui->slotToggleLogBrowser(); // _showLogWindow is set in parseOptions.
-        }
         if (_showSettings) {
             _gui->slotShowSettings();
         }
         if (_quitInstance) {
             qApp->quit();
         }
-
-    } else if (msg.startsWith(QLatin1String("MSG_SHOWSETTINGS"))) {
-#ifdef Q_OS_LINUX
-        qCInfo(lcApplication) << "Running for" << _startedAt.elapsed() / 1000.0 << "sec";
-        if (_startedAt.elapsed() < 10 * 1000) {
-            // This call is mirrored with the one in int main()
-            qCWarning(lcApplication) << "Ignoring MSG_SHOWSETTINGS, possibly double-invocation of client via session restore and auto start";
-            return;
-        }
-#endif
-        showSettingsDialog();
-    }
-}
-
-void Application::parseOptions(const QStringList &options)
-{
-    QStringListIterator it(options);
-    // skip file name;
-    if (it.hasNext())
-        it.next();
-
-    //parse options; if help or bad option exit
-    while (it.hasNext()) {
-        QString option = it.next();
-        if (option == QLatin1String("--help") || option == QLatin1String("-h")) {
-            setHelp();
-            break;
-        } else if (option == QLatin1String("--showsettings") || option == QLatin1String("-s")) {
-            _showSettings = true;
-        } else if (option == QLatin1String("--quit") || option == QLatin1String("-q")) {
-            _quitInstance = true;
-        } else if (option == QLatin1String("--logwindow") || option == QLatin1String("-l")) {
-            _showLogWindow = true;
-        } else if (option == QLatin1String("--logfile")) {
-            if (it.hasNext() && !it.peekNext().startsWith(QLatin1String("--"))) {
-                _logFile = it.next();
-            } else {
-                showHint("Log file not specified");
-            }
-        } else if (option == QLatin1String("--logdir")) {
-            if (it.hasNext() && !it.peekNext().startsWith(QLatin1String("--"))) {
-                _logDir = it.next();
-            } else {
-                showHint("Log dir not specified");
-            }
-        } else if (option == QLatin1String("--logexpire")) {
-            if (it.hasNext() && !it.peekNext().startsWith(QLatin1String("--"))) {
-                _logExpire = std::chrono::hours(it.next().toInt());
-            } else {
-                showHint("Log expiration not specified");
-            }
-        } else if (option == QLatin1String("--logflush")) {
-            _logFlush = true;
-        } else if (option == QLatin1String("--logdebug")) {
-            _logDebug = true;
-        } else if (option == QLatin1String("--confdir")) {
-            if (it.hasNext() && !it.peekNext().startsWith(QLatin1String("--"))) {
-                QString confDir = it.next();
-                if (!ConfigFile::setConfDir(confDir)) {
-                    showHint("Invalid path passed to --confdir");
-                }
-            } else {
-                showHint("Path for confdir not specified");
-            }
-        } else if (option == QLatin1String("--debug")) {
-            _logDebug = true;
-            _debugMode = true;
-        } else if (option == QLatin1String("--version")) {
-            _versionOnly = true;
-        } else if (option.endsWith(QStringLiteral(APPLICATION_DOTVIRTUALFILE_SUFFIX))) {
-            // virtual file, open it after the Folder were created (if the app is not terminated)
-            QTimer::singleShot(0, this, [this, option] { openVirtualFile(option); });
-        } else {
-            showHint("Unrecognized option '" + option.toStdString() + "'");
-        }
     }
 }
 
 // Helpers for displaying messages. Note that there is probably no console on Windows.
-static void displayHelpText(const QString &t)
+static void displayHelpText(const QString &t, std::ostream &stream = std::cout)
 {
-    std::cout << qUtf8Printable(t) << std::endl;
+    Logger::instance()->attacheToConsole();
+    stream << qUtf8Printable(t) << std::endl;
 #ifdef Q_OS_WIN
     // No console on Windows.
     QString spaces(80, ' '); // Add a line of non-wrapped space to make the messagebox wide enough.
-    QString text = QLatin1String("<qt><pre style='white-space:pre-wrap'>")
-        + t.toHtmlEscaped() + QLatin1String("</pre><pre>") + spaces + QLatin1String("</pre></qt>");
+    QString text = QStringLiteral("<qt><pre style='white-space:pre-wrap'>")
+        + t.toHtmlEscaped() + QStringLiteral("</pre><pre>") + spaces + QStringLiteral("</pre></qt>");
     QMessageBox::information(0, Theme::instance()->appNameGUI(), text);
 #endif
 }
 
-void Application::showHelp()
+void Application::parseOptions(const QStringList &arguments)
 {
-    setHelp();
-    QString helpText;
-    QTextStream stream(&helpText);
-    stream << _theme->appName()
-           << QLatin1String(" version ")
-           << _theme->version() << endl;
+    QCommandLineParser parser;
 
-    stream << QLatin1String("File synchronisation desktop utility.") << endl
-           << endl
-           << optionsC();
+    QString descriptionText;
+    QTextStream descriptionTextStream(&descriptionText);
+
+    descriptionTextStream << tr("%1 version %2\r\nFile synchronization desktop utility.").arg(_theme->appName(), _theme->version()) << endl;
 
     if (_theme->appName() == QLatin1String("ownCloud")) {
-        stream << endl
-               << endl
-               << "For more information, see http://www.owncloud.org";
+        descriptionTextStream << endl
+                              << endl
+                              << tr("For more information, see http://www.owncloud.org");
     }
 
-    displayHelpText(helpText);
-}
+    parser.setApplicationDescription(descriptionText);
 
-void Application::showVersion()
-{
-    displayHelpText(Theme::instance()->versionSwitchOutput());
-}
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
 
-void Application::showHint(std::string errorHint)
-{
-    static QString binName = QFileInfo(QCoreApplication::applicationFilePath()).fileName();
-    std::cerr << errorHint << std::endl;
-    std::cerr << "Try '" << binName.toStdString() << " --help' for more information" << std::endl;
-    std::exit(1);
+    // this little snippet saves a few lines below
+    auto addOption = [&parser](const QCommandLineOption &option) {
+        parser.addOption(option);
+        return option;
+    };
+
+    auto showSettingsOption = addOption({ { "s", "showsettings" }, tr("Show the settings dialog while starting.") });
+    auto quitInstanceOption = addOption({ { "q", "quit" }, tr("Quit the running instance.") });
+    auto logFileOption = addOption({ "logfile", tr("Write log to file (use - to write to stdout)."), "filename" });
+    auto logDirOption = addOption({ "logdir", tr("Write each sync log output in a new file in folder."), "name" });
+    auto logExpireOption = addOption({ "logexpire", tr("Remove logs older than <hours> hours (to be used with --logdir)."), "hours" });
+    auto logFlushOption = addOption({ "logflush", tr("Flush the log file after every write.") });
+    auto logDebugOption = addOption({ "logdebug", tr("Output debug-level messages in the log.") });
+    auto languageOption = addOption({ "language", tr("Override UI language."), "language" });
+    auto listLanguagesOption = addOption({ "list-languages", tr("Override UI language.") });
+    auto confDirOption = addOption({ "confdir", tr("Use the given configuration folder."), "dirname" });
+    auto debugOption = addOption({ "debug", tr("Enable debug mode.") });
+
+    // virtual file system parameters (optional)
+    parser.addPositionalArgument("vfs file", tr("Virtual file system file to be opened (optional)."), { tr("[<vfs file>]") });
+
+    parser.process(arguments);
+
+    // TODO: rename this option (see #8234 for more information)
+    if (parser.isSet(showSettingsOption)) {
+        _showSettings = true;
+    }
+    if (parser.isSet(quitInstanceOption)) {
+        _quitInstance = true;
+    }
+    if (parser.isSet(logFileOption)) {
+        _logFile = parser.value(logFileOption);
+    }
+    if (parser.isSet(logDirOption)) {
+        _logDir = parser.value(logDirOption);
+    }
+    if (parser.isSet(logExpireOption)) {
+        _logExpire = std::chrono::hours(parser.value(logExpireOption).toInt());
+    }
+    if (parser.isSet(logFlushOption)) {
+        _logFlush = true;
+    }
+    if (parser.isSet(logDebugOption)) {
+        _logDebug = true;
+    }
+    if (parser.isSet(confDirOption)) {
+        const auto confDir = parser.value(confDirOption);
+        if (!ConfigFile::setConfDir(confDir)) {
+            displayHelpText(tr("Invalid path passed to --confdir"));
+            std::exit(1);
+        }
+    }
+    if (parser.isSet(debugOption)) {
+        _logDebug = true;
+        _debugMode = true;
+    }
+    if (parser.isSet(languageOption)) {
+        const auto languageValue = parser.value(languageOption);
+
+        // fail if the language is unknown
+        if (!Translations::listAvailableTranslations().contains(languageValue)) {
+            displayHelpText(tr("Error: unknown language \"%1\" (use --list-languages to get a complete list of supported translations)").arg(languageValue));
+            std::exit(1);
+        } else {
+            _userEnforcedLanguage = languageValue;
+        }
+    }
+    if (parser.isSet(listLanguagesOption)) {
+        auto availableTranslations = Translations::listAvailableTranslations().toList();
+        availableTranslations.sort(Qt::CaseInsensitive);
+        displayHelpText(tr("Available translations: %1").arg(availableTranslations.join(", ")));
+        std::exit(1);
+    }
+
+    auto positionalArguments = parser.positionalArguments();
+
+    // ignore any positional arguments beyond the first one
+    if (!positionalArguments.empty()) {
+        QTimer::singleShot(0, this, [this, positionalArguments] { openVirtualFile(positionalArguments.front()); });
+    }
 }
 
 bool Application::debugMode()
@@ -681,11 +671,6 @@ bool Application::debugMode()
     return _debugMode;
 }
 
-void Application::setHelp()
-{
-    _helpOnly = true;
-}
-
 QString substLang(const QString &lang)
 {
     // Map the more appropriate script codes
@@ -703,21 +688,38 @@ QString substLang(const QString &lang)
 
 void Application::setupTranslations()
 {
+    const auto trPath = Translations::translationsDirectoryPath();
+
     QStringList uiLanguages = QLocale::system().uiLanguages();
 
-    QString enforcedLocale = Theme::instance()->enforcedLocale();
-    if (!enforcedLocale.isEmpty())
-        uiLanguages.prepend(enforcedLocale);
+    // the user can also set a locale in the settings, so we need to load the config file
+    ConfigFile cfg;
+
+    // allow user and theme to enforce a language via a commandline parameter
+    const auto themeEnforcedLocale = Theme::instance()->enforcedLocale();
+
+    // we need to track the enforced languages separately, since we need to distinguish between locale-provided
+    // and user-enforced ones below
+    QSet<QString> enforcedLanguages;
+
+    // note that user-enforced languages are prioritized over the theme enforced one
+    // to make testing easier, --language overrides the setting from the config file
+    // as we are prepending to the list of languages, the list passed to the loop must be sorted with ascending priority
+    for (const auto &enforcedLocale : { themeEnforcedLocale, cfg.uiLanguage(), _userEnforcedLanguage }) {
+        if (!enforcedLocale.isEmpty()) {
+            enforcedLanguages.insert(enforcedLocale);
+            uiLanguages.prepend(enforcedLocale);
+        }
+    }
 
     QTranslator *translator = new QTranslator(this);
     QTranslator *qtTranslator = new QTranslator(this);
     QTranslator *qtkeychainTranslator = new QTranslator(this);
 
-    foreach (QString lang, uiLanguages) {
+    for (QString lang : qAsConst(uiLanguages)) {
         lang.replace(QLatin1Char('-'), QLatin1Char('_')); // work around QTBUG-25973
         lang = substLang(lang);
-        const QString trPath = applicationTrPath();
-        const QString trFile = QLatin1String("client_") + lang;
+        const QString trFile = Translations::translationsFilePrefix() + lang;
         if (translator->load(trFile, trPath) || lang.startsWith(QLatin1String("en"))) {
             // Permissive approach: Qt and keychain translations
             // may be missing, but Qt translations must be there in order
@@ -725,7 +727,7 @@ void Application::setupTranslations()
             // "en" is an exception as it is the default language and may not
             // have a translation file provided.
             qCInfo(lcApplication) << "Using" << lang << "translation";
-            setProperty("ui_lang", lang);
+            _displayLanguage = lang;
             const QString qtTrPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
             const QString qtTrFile = QLatin1String("qt_") + lang;
             const QString qtBaseTrFile = QLatin1String("qtbase_") + lang;
@@ -746,23 +748,23 @@ void Application::setupTranslations()
                 installTranslator(qtTranslator);
             if (!qtkeychainTranslator->isEmpty())
                 installTranslator(qtkeychainTranslator);
+
+            // makes sure widgets with locale-dependent formatting, e.g., QDateEdit, display the correct formatting
+            // if the language is provided by the system locale anyway (i.e., coming from QLocale::system().uiLanguages()), we should
+            // not mess with the system locale, though
+            // if we did, we would enforce a locale for no apparent reason
+            // see https://github.com/owncloud/client/issues/8608 for more information
+            if (enforcedLanguages.contains(lang)) {
+                QLocale newLocale(lang);
+                qCDebug(lcApplication) << "language" << lang << "was enforced, changing default locale to" << newLocale;
+                QLocale::setDefault(newLocale);
+            }
+
             break;
         }
-        if (property("ui_lang").isNull())
-            setProperty("ui_lang", "C");
     }
 }
 
-bool Application::giveHelp()
-{
-    return _helpOnly;
-}
-
-bool Application::versionOnly()
-{
-    return _versionOnly;
-}
-
 void Application::showSettingsDialog()
 {
     _gui->slotShowSettings();
