@@ -68,6 +68,7 @@ Folder::Folder(const FolderDefinition &definition,
 {
     _timeSinceLastSyncStart.start();
     _timeSinceLastSyncDone.start();
+    _timeSinceLastEtagCheckDone.start();
 
     SyncResult::Status status = SyncResult::NotYetStarted;
     if (definition.paused) {
@@ -89,7 +90,7 @@ Folder::Folder(const FolderDefinition &definition,
         qCWarning(lcFolder, "Could not read system exclude file");
 
     connect(_accountState.data(), &AccountState::isConnectedChanged, this, &Folder::canSyncChanged);
-    connect(_engine.data(), &SyncEngine::rootEtag, this, &Folder::etagRetreivedFromSyncEngine);
+    connect(_engine.data(), &SyncEngine::rootEtag, this, &Folder::etagRetrievedFromSyncEngine);
 
     connect(_engine.data(), &SyncEngine::started, this, &Folder::slotSyncStarted, Qt::QueuedConnection);
     connect(_engine.data(), &SyncEngine::finished, this, &Folder::slotSyncFinished, Qt::QueuedConnection);
@@ -113,6 +114,9 @@ Folder::Folder(const FolderDefinition &definition,
 
     connect(ProgressDispatcher::instance(), &ProgressDispatcher::folderConflicts,
         this, &Folder::slotFolderConflicts);
+    connect(_engine.data(), &SyncEngine::excluded, this, [this](const QString &path, CSYNC_EXCLUDE_TYPE reason) {
+        Q_EMIT ProgressDispatcher::instance()->excluded(this, path, reason);
+    });
 
     _localDiscoveryTracker.reset(new LocalDiscoveryTracker);
     connect(_engine.data(), &SyncEngine::finished,
@@ -282,6 +286,26 @@ bool Folder::canSync() const
     return !syncPaused() && accountState()->isConnected();
 }
 
+bool Folder::dueToSync() const
+{
+    // conditions taken from previous folderman implementation
+    if (isSyncRunning() || etagJob() || isBusy() || !canSync()) {
+        return false;
+    }
+
+    ConfigFile cfg;
+    // the default poll time of 30 seconds as it had been in the client forever.
+    // Now with https://github.com/owncloud/client/pull/8777 also the server capabilities are considered.
+    const auto pta = accountState()->account()->capabilities().remotePollInterval();
+    const auto polltime = cfg.remotePollInterval(pta);
+
+    const auto timeSinceLastSync = std::chrono::milliseconds(_timeSinceLastEtagCheckDone.elapsed());
+    if (timeSinceLastSync >= polltime) {
+        return true;
+    }
+    return false;
+}
+
 void Folder::setSyncPaused(bool paused)
 {
     if (paused == _definition.paused) {
@@ -340,11 +364,12 @@ void Folder::slotRunEtagJob()
     _requestEtagJob->setTimeout(60 * 1000);
     // check if the etag is different when retrieved
     QObject::connect(_requestEtagJob.data(), &RequestEtagJob::etagRetreived, this, &Folder::etagRetreived);
+    QObject::connect(_requestEtagJob.data(), &RequestEtagJob::finishedWithResult, this, [=](const HttpResult<QByteArray>) { _timeSinceLastEtagCheckDone.start(); });
     FolderMan::instance()->slotScheduleETagJob(alias(), _requestEtagJob);
     // The _requestEtagJob is auto deleting itself on finish. Our guard pointer _requestEtagJob will then be null.
 }
 
-void Folder::etagRetreived(const QString &etag)
+void Folder::etagRetreived(const QByteArray &etag, const QDateTime &tp)
 {
     // re-enable sync if it was disabled because network was down
     FolderMan::instance()->setSyncEnabled(true);
@@ -355,13 +380,13 @@ void Folder::etagRetreived(const QString &etag)
         slotScheduleThisFolder();
     }
 
-    _accountState->tagLastSuccessfullETagRequest();
+    _accountState->tagLastSuccessfullETagRequest(tp);
 }
 
-void Folder::etagRetreivedFromSyncEngine(const QString &etag)
+void Folder::etagRetrievedFromSyncEngine(const QByteArray &etag, const QDateTime &time)
 {
     qCInfo(lcFolder) << "Root etag from during sync:" << etag;
-    accountState()->tagLastSuccessfullETagRequest();
+    accountState()->tagLastSuccessfullETagRequest(time);
     _lastEtag = etag;
 }
 
@@ -404,8 +429,6 @@ void Folder::createGuiLog(const QString &filename, LogStatus status, int count,
     const QString &renameTarget)
 {
     if (count > 0) {
-        Logger *logger = Logger::instance();
-
         QString file = QDir::toNativeSeparators(filename);
         QString text;
 
@@ -504,7 +527,7 @@ int Folder::slotDiscardDownloadProgress()
     QSet<QString> keep_nothing;
     const QVector<SyncJournalDb::DownloadInfo> deleted_infos =
         _journal.getAndDeleteStaleDownloadInfos(keep_nothing);
-    foreach (const SyncJournalDb::DownloadInfo &deleted_info, deleted_infos) {
+    for (const auto &deleted_info : deleted_infos) {
         const QString tmppath = folderpath.filePath(deleted_info._tmpfile);
         qCInfo(lcFolder) << "Deleting temporary file: " << tmppath;
         FileSystem::remove(tmppath);
@@ -529,7 +552,7 @@ int Folder::slotWipeErrorBlacklist()
 
 void Folder::slotWatchedPathChanged(const QString &path, ChangeReason reason)
 {
-    if (!path.startsWith(this->path())) {
+    if (!FileSystem::isChildPathOf(path, this->path())) {
         qCDebug(lcFolder) << "Changed path is not contained in folder, ignoring:" << path;
         return;
     }
@@ -673,7 +696,7 @@ void Folder::saveToSettings() const
 
     // True if the folder path appears in only one account
     bool oneAccountOnly = true;
-    foreach (Folder *other, FolderMan::instance()->map()) {
+    for (auto *other : FolderMan::instance()->map()) {
         if (other != this && other->cleanPath() == this->cleanPath()) {
             oneAccountOnly = false;
             break;
@@ -792,8 +815,8 @@ void Folder::startSync(const QStringList &pathList)
     _syncResult.setStatus(SyncResult::SyncPrepare);
     emit syncStateChange();
 
-    qCInfo(lcFolder) << "*** Start syncing " << remoteUrl().toString() << " -" << APPLICATION_NAME << "client version"
-                     << qPrintable(Theme::instance()->version());
+    qCInfo(lcFolder) << "*** Start syncing " << remoteUrl().toString() << "client version"
+                     << Theme::instance()->aboutVersions(Theme::VersionFormat::OneLiner);
 
     _fileLog->start(path());
 
@@ -899,10 +922,7 @@ void Folder::slotSyncStarted()
 
 void Folder::slotSyncFinished(bool success)
 {
-    qCInfo(lcFolder) << "Client version" << qPrintable(Theme::instance()->version())
-                     << " Qt" << qVersion()
-                     << " SSL " << QSslSocket::sslLibraryVersionString().toUtf8().data()
-        ;
+    qCInfo(lcFolder) << "Client version" << Theme::instance()->aboutVersions(Theme::VersionFormat::OneLiner);
 
     bool syncError = !_syncResult.errorStrings().isEmpty();
     if (syncError) {
@@ -1007,7 +1027,8 @@ void Folder::slotTransmissionProgress(const ProgressInfo &pi)
 // a item is completed: count the errors and forward to the ProgressDispatcher
 void Folder::slotItemCompleted(const SyncFileItemPtr &item)
 {
-    if (item->_instruction == CSYNC_INSTRUCTION_NONE || item->_instruction == CSYNC_INSTRUCTION_UPDATE_METADATA) {
+    if (item->_status == SyncFileItem::Success
+        && (item->_instruction & (CSYNC_INSTRUCTION_NONE | CSYNC_INSTRUCTION_UPDATE_METADATA))) {
         // We only care about the updates that deserve to be shown in the UI
         return;
     }
@@ -1189,11 +1210,11 @@ bool Folder::virtualFilesEnabled() const
     return _definition.virtualFilesMode != Vfs::Off && !isVfsOnOffSwitchPending();
 }
 
-void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, std::function<void(bool)> callback)
+void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, std::function<void(bool)> abort)
 {
     ConfigFile cfgFile;
     if (!cfgFile.promptDeleteFiles()) {
-        callback(false);
+        abort(false);
         return;
     }
     const QString msg = dir == SyncFileItem::Down ? tr("All files in the sync folder '%1' folder were deleted on the server.\n"
@@ -1213,9 +1234,9 @@ void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, std::functio
     QPushButton *keepBtn = msgBox->addButton(tr("Keep files"), QMessageBox::AcceptRole);
     bool oldPaused = syncPaused();
     setSyncPaused(true);
-    connect(msgBox, &QMessageBox::finished, this, [msgBox, keepBtn, callback, oldPaused, this] {
+    connect(msgBox, &QMessageBox::finished, this, [msgBox, keepBtn, abort, oldPaused, this] {
         const bool cancel = msgBox->clickedButton() == keepBtn;
-        callback(cancel);
+        abort(cancel);
         if (cancel) {
             FileSystem::setFolderMinimumPermissions(path());
             journalDb()->clearFileTable();
@@ -1319,7 +1340,7 @@ QString FolderDefinition::absoluteJournalPath() const
 
 QString FolderDefinition::defaultJournalPath(AccountPtr account)
 {
-    return SyncJournalDb::makeDbName(localPath, account->url(), targetPath, account->credentials()->user());
+    return SyncJournalDb::makeDbName(localPath, QStringLiteral("journal"));
 }
 
 } // namespace OCC
