@@ -36,13 +36,75 @@
 #include <QSet>
 #include <QNetworkProxy>
 
-static const char versionC[] = "version";
-static const int maxFoldersVersion = 1;
+namespace {
+const char versionC[] = "version";
+const int maxFoldersVersion = 1;
+
+int numberOfSyncJournals(const QString &path)
+{
+    return QDir(path).entryList({ QStringLiteral(".sync_*.db"), QStringLiteral("._sync_*.db") }, QDir::Hidden | QDir::Files).size();
+}
+
+}
 
 namespace OCC {
-
 Q_LOGGING_CATEGORY(lcFolderMan, "gui.folder.manager", QtInfoMsg)
 
+void TrayOverallStatusResult::addResult(Folder *f)
+{
+    _overallStatus._numNewConflictItems += f->syncResult()._numNewConflictItems;
+    _overallStatus._numErrorItems += f->syncResult()._numErrorItems;
+    _overallStatus._numBlacklistErrors += f->syncResult()._numBlacklistErrors;
+
+    auto time = f->lastSyncTime();
+    if (time > lastSyncDone) {
+        lastSyncDone = time;
+    }
+
+    const auto status = f->syncPaused() ? SyncResult::Paused : f->syncResult().status();
+    switch (status) {
+    case SyncResult::Paused:
+        Q_FALLTHROUGH();
+    case SyncResult::SyncAbortRequested:
+        // Problem has a high enum value but real problems and errors
+        // take precedence
+        if (_overallStatus.status() < SyncResult::Success) {
+            _overallStatus.setStatus(status);
+        }
+        break;
+    case SyncResult::Success:
+        Q_FALLTHROUGH();
+    case SyncResult::NotYetStarted:
+        Q_FALLTHROUGH();
+    case SyncResult::SyncPrepare:
+        Q_FALLTHROUGH();
+    case SyncResult::SyncRunning:
+        if (_overallStatus.status() < SyncResult::Problem) {
+            _overallStatus.setStatus(status);
+        }
+        break;
+    case SyncResult::Undefined:
+        if (_overallStatus.status() < SyncResult::Problem) {
+            _overallStatus.setStatus(SyncResult::Problem);
+        }
+        break;
+    case SyncResult::Problem:
+        Q_FALLTHROUGH();
+    case SyncResult::Error:
+        Q_FALLTHROUGH();
+    case SyncResult::SetupError:
+        if (_overallStatus.status() < status) {
+            _overallStatus.setStatus(status);
+        }
+        break;
+    }
+}
+
+const SyncResult &TrayOverallStatusResult::overallStatus() const
+{
+    return _overallStatus;
+}
+
 FolderMan *FolderMan::_instance = nullptr;
 
 FolderMan::FolderMan(QObject *parent)
@@ -60,10 +122,10 @@ FolderMan::FolderMan(QObject *parent)
 
     _socketApi.reset(new SocketApi);
 
-    ConfigFile cfg;
-    std::chrono::milliseconds polltime = cfg.remotePollInterval();
-    qCInfo(lcFolderMan) << "setting remote poll timer interval to" << polltime.count() << "msec";
-    _etagPollTimer.setInterval(polltime.count());
+    // Set the remote poll interval fixed to 10 seconds.
+    // That does not mean that it polls every 10 seconds, but it checks every 10 secs
+    // if one of the folders is due to sync.
+    _etagPollTimer.setInterval(1000);
     QObject::connect(&_etagPollTimer, &QTimer::timeout, this, &FolderMan::slotEtagPollTimerTimeout);
     _etagPollTimer.start();
 
@@ -95,21 +157,14 @@ FolderMan::~FolderMan()
     _instance = nullptr;
 }
 
-const OCC::Folder::Map &FolderMan::map() const
+const QMap<QString, Folder *> &FolderMan::map() const
 {
     return _folderMap;
 }
 
-QList<Folder *> FolderMan::list() const
-{
-    return _folderMap.values();
-}
-
 void FolderMan::unloadFolder(Folder *f)
 {
-    if (!f) {
-        return;
-    }
+    Q_ASSERT(f);
 
     _socketApi->slotUnregisterPath(f->alias());
 
@@ -127,30 +182,23 @@ void FolderMan::unloadFolder(Folder *f)
         _socketApi.data(), &SocketApi::broadcastStatusPushMessage);
     disconnect(f, &Folder::watchedFileChangedExternally,
         &f->syncEngine().syncFileStatusTracker(), &SyncFileStatusTracker::slotPathTouched);
+
+    f->syncEngine().disconnect(f);
 }
 
-int FolderMan::unloadAndDeleteAllFolders()
+void FolderMan::unloadAndDeleteAllFolders()
 {
-    int cnt = 0;
-
     // clear the list of existing folders.
-    Folder::MapIterator i(_folderMap);
-    while (i.hasNext()) {
-        i.next();
-        Folder *f = i.value();
-        unloadFolder(f);
-        delete f;
-        cnt++;
+    const auto folders = std::move(_folderMap);
+    for (auto *folder : folders) {
+        _socketApi->slotUnregisterPath(folder->alias());
+        folder->deleteLater();
     }
-    OC_ASSERT(_folderMap.isEmpty());
-
     _lastSyncFolder = nullptr;
     _currentSyncFolder = nullptr;
     _scheduledFolders.clear();
     emit folderListChanged(_folderMap);
     emit scheduleQueueChanged();
-
-    return cnt;
 }
 
 void FolderMan::registerFolderWithSocketApi(Folder *folder)
@@ -176,7 +224,7 @@ int FolderMan::setupFolders()
     skipSettingsKeys += deleteSettingsKeys;
 
     auto settings = ConfigFile::settingsWithGroup(QLatin1String("Accounts"));
-    const auto accountsWithSettings = settings->childGroups();
+    const auto &accountsWithSettings = settings->childGroups();
     if (accountsWithSettings.isEmpty()) {
         int r = setupFoldersMigration();
         if (r > 0) {
@@ -187,7 +235,7 @@ int FolderMan::setupFolders()
 
     qCInfo(lcFolderMan) << "Setup folders from settings file";
 
-    foreach (const auto &account, AccountManager::instance()->accounts()) {
+    for (const auto &account : AccountManager::instance()->accounts()) {
         const auto id = account->account()->id();
         if (!accountsWithSettings.contains(id)) {
             continue;
@@ -223,7 +271,8 @@ int FolderMan::setupFolders()
 
 void FolderMan::setupFoldersHelper(QSettings &settings, AccountStatePtr account, const QStringList &ignoreKeys, bool backwardsCompatible, bool foldersWithPlaceholders)
 {
-    foreach (const auto &folderAlias, settings.childGroups()) {
+    const auto &childGroups = settings.childGroups();
+    for (const auto &folderAlias : childGroups) {
         // Skip folders with too-new version
         settings.beginGroup(folderAlias);
         if (ignoreKeys.contains(settings.group())) {
@@ -290,20 +339,18 @@ void FolderMan::setupFoldersHelper(QSettings &settings, AccountStatePtr account,
 
 int FolderMan::setupFoldersMigration()
 {
-    ConfigFile cfg;
-    QDir storageDir(cfg.configPath());
-    _folderConfigPath = cfg.configPath() + QLatin1String("folders");
+    _folderConfigPath = ConfigFile::configPath() + QLatin1String("folders");
 
     qCInfo(lcFolderMan) << "Setup folders from " << _folderConfigPath << "(migration)";
 
     QDir dir(_folderConfigPath);
     //We need to include hidden files just in case the alias starts with '.'
     dir.setFilter(QDir::Files | QDir::Hidden);
-    QStringList list = dir.entryList();
+    const auto &list = dir.entryList();
 
     // Normally there should be only one account when migrating.
     AccountState *accountState = AccountManager::instance()->accounts().value(0).data();
-    foreach (const QString &alias, list) {
+    for (const auto &alias : list) {
         Folder *f = setupFolderFromOldConfigFile(alias, accountState);
         if (f) {
             scheduleFolder(f);
@@ -325,7 +372,8 @@ void FolderMan::backwardMigrationSettingsKeys(QStringList *deleteKeys, QStringLi
         settings->beginGroup(name);
         const int foldersVersion = settings->value(QLatin1String(versionC), 1).toInt();
         if (foldersVersion <= maxFoldersVersion) {
-            foreach (const auto &folderAlias, settings->childGroups()) {
+            const auto &childGroups = settings->childGroups();
+            for (const auto &folderAlias : childGroups) {
                 settings->beginGroup(folderAlias);
                 const int folderVersion = settings->value(QLatin1String(versionC), 1).toInt();
                 if (folderVersion > FolderDefinition::maxSettingsVersion()) {
@@ -339,7 +387,8 @@ void FolderMan::backwardMigrationSettingsKeys(QStringList *deleteKeys, QStringLi
         settings->endGroup();
     };
 
-    for (const auto &accountId : settings->childGroups()) {
+    const auto &childGroups = settings->childGroups();
+    for (const auto &accountId : childGroups) {
         settings->beginGroup(accountId);
         processSubgroup("Folders");
         processSubgroup("Multifolders");
@@ -536,16 +585,14 @@ void FolderMan::slotFolderCanSyncChanged()
 Folder *FolderMan::folder(const QString &alias)
 {
     if (!alias.isEmpty()) {
-        if (_folderMap.contains(alias)) {
-            return _folderMap[alias];
-        }
+        return _folderMap.value(alias);
     }
     return nullptr;
 }
 
 void FolderMan::scheduleAllFolders()
 {
-    foreach (Folder *f, _folderMap.values()) {
+    for (auto *f : qAsConst(_folderMap)) {
         if (f && f->canSync()) {
             scheduleFolder(f);
         }
@@ -558,9 +605,9 @@ void FolderMan::slotScheduleAppRestart()
     qCInfo(lcFolderMan) << "Application restart requested!";
 }
 
-void FolderMan::slotSyncOnceFileUnlocks(const QString &path)
+void FolderMan::slotSyncOnceFileUnlocks(const QString &path, FileSystem::LockMode mode)
 {
-    _lockWatcher->addFile(path);
+    _lockWatcher->addFile(path, mode);
 }
 
 /*
@@ -632,7 +679,7 @@ void FolderMan::slotRunOneEtagJob()
 {
     if (_currentEtagJob.isNull()) {
         Folder *folder = nullptr;
-        foreach (Folder *f, _folderMap) {
+        for (auto *f : qAsConst(_folderMap)) {
             if (f->etagJob()) {
                 // Caveat: always grabs the first folder with a job, but we think this is Ok for now and avoids us having a seperate queue.
                 _currentEtagJob = f->etagJob();
@@ -665,7 +712,7 @@ void FolderMan::slotAccountStateChanged()
     if (accountState->isConnected()) {
         qCInfo(lcFolderMan) << "Account" << accountName << "connected, scheduling its folders";
 
-        foreach (Folder *f, _folderMap.values()) {
+        for (auto *f : qAsConst(_folderMap)) {
             if (f
                 && f->canSync()
                 && f->accountState() == accountState) {
@@ -676,7 +723,7 @@ void FolderMan::slotAccountStateChanged()
         qCInfo(lcFolderMan) << "Account" << accountName << "disconnected or paused, "
                                                            "terminating or descheduling sync folders";
 
-        foreach (Folder *f, _folderMap.values()) {
+        for (auto *f : qAsConst(_folderMap)) {
             if (f
                 && f->isSyncRunning()
                 && f->accountState() == accountState) {
@@ -705,7 +752,7 @@ void FolderMan::setSyncEnabled(bool enabled)
     }
     _syncEnabled = enabled;
     // force a redraw in case the network connect status changed
-    emit(folderSyncStateChange(nullptr));
+    Q_EMIT folderSyncStateChange(nullptr);
 }
 
 void FolderMan::startScheduledSyncSoon()
@@ -755,7 +802,7 @@ void FolderMan::startScheduledSyncSoon()
 void FolderMan::slotStartScheduledFolderSync()
 {
     if (isAnySyncRunning()) {
-        for (auto f : _folderMap) {
+        for (auto *f : qAsConst(_folderMap)) {
             if (f->isSyncRunning())
                 qCInfo(lcFolderMan) << "Currently folder " << f->remoteUrl().toString() << " is running, wait for finish!";
         }
@@ -798,45 +845,33 @@ void FolderMan::slotStartScheduledFolderSync()
 
 void FolderMan::slotEtagPollTimerTimeout()
 {
-    ConfigFile cfg;
-    auto polltime = cfg.remotePollInterval();
-
-    foreach (Folder *f, _folderMap) {
+    for (auto *f : qAsConst(_folderMap)) {
         if (!f) {
             continue;
         }
-        if (f->isSyncRunning()) {
-            continue;
-        }
         if (_scheduledFolders.contains(f)) {
             continue;
         }
         if (_disabledFolders.contains(f)) {
             continue;
         }
-        if (f->etagJob() || f->isBusy() || !f->canSync()) {
-            continue;
+        if (f->dueToSync()) {
+            QMetaObject::invokeMethod(f, &Folder::slotRunEtagJob, Qt::QueuedConnection);
         }
-        if (f->msecSinceLastSync() < polltime) {
-            continue;
-        }
-        QMetaObject::invokeMethod(f, "slotRunEtagJob", Qt::QueuedConnection);
     }
 }
 
 void FolderMan::slotRemoveFoldersForAccount(AccountState *accountState)
 {
-    QVarLengthArray<Folder *, 16> foldersToRemove;
-    Folder::MapIterator i(_folderMap);
-    while (i.hasNext()) {
-        i.next();
-        Folder *folder = i.value();
+    QList<Folder *> foldersToRemove;
+    // reserve a magic number
+    foldersToRemove.reserve(16);
+    for (auto *folder : qAsConst(_folderMap)) {
         if (folder->accountState() == accountState) {
             foldersToRemove.append(folder);
         }
     }
-
-    foreach (const auto &f, foldersToRemove) {
+    for (const auto &f : foldersToRemove) {
         removeFolder(f);
     }
 }
@@ -855,7 +890,7 @@ void FolderMan::slotServerVersionChanged(Account *account)
         qCWarning(lcFolderMan) << "The server version is unsupported:" << account->serverVersion()
                                << "pausing all folders on the account";
 
-        foreach (auto &f, _folderMap) {
+        for (auto &f : qAsConst(_folderMap)) {
             if (f->accountState()->account().data() == account) {
                 f->setSyncPaused(true);
             }
@@ -873,7 +908,7 @@ void FolderMan::slotWatchedFileUnlocked(const QString &path)
 
 void FolderMan::slotScheduleFolderByTime()
 {
-    foreach (auto &f, _folderMap) {
+    for (const auto &f : qAsConst(_folderMap)) {
         // Never schedule if syncing is disabled or when we're currently
         // querying the server for etags
         if (!f->canSync() || f->etagJob()) {
@@ -883,7 +918,8 @@ void FolderMan::slotScheduleFolderByTime()
         auto msecsSinceSync = f->msecSinceLastSync();
 
         // Possibly it's just time for a new sync run
-        bool forceSyncIntervalExpired = msecsSinceSync > ConfigFile().forceSyncInterval();
+        const auto pta = f->accountState()->account()->capabilities().remotePollInterval();
+        bool forceSyncIntervalExpired = msecsSinceSync > ConfigFile().forceSyncInterval(pta);
         if (forceSyncIntervalExpired) {
             qCInfo(lcFolderMan) << "Scheduling folder" << f->alias()
                                 << "because it has been" << msecsSinceSync.count() << "ms "
@@ -934,10 +970,13 @@ void FolderMan::slotFolderSyncStarted()
     if (!f)
         return;
 
-    qCInfo(lcFolderMan, ">========== Sync started for folder [%s] of account [%s] with remote [%s]",
-        qPrintable(f->shortGuiLocalPath()),
-        qPrintable(f->accountState()->account()->displayName()),
-        qPrintable(f->remoteUrl().toString()));
+    qCInfo(lcFolderMan) << ">========== Sync started for folder ["
+                        << f->shortGuiLocalPath()
+                        << "] of account ["
+                        << f->accountState()->account()->displayName()
+                        << "] with remote ["
+                        << f->remoteUrl().toDisplayString()
+                        << "]";
 }
 
 /*
@@ -953,11 +992,13 @@ void FolderMan::slotFolderSyncFinished(const SyncResult &)
     if (!f)
         return;
 
-    qCInfo(lcFolderMan, "<========== Sync finished for folder [%s] of account [%s] with remote [%s]",
-        qPrintable(f->shortGuiLocalPath()),
-        qPrintable(f->accountState()->account()->displayName()),
-        qPrintable(f->remoteUrl().toString()));
-
+    qCInfo(lcFolderMan) << "<========== Sync finished for folder ["
+                        << f->shortGuiLocalPath()
+                        << "] of account ["
+                        << f->accountState()->account()->displayName()
+                        << "] with remote ["
+                        << f->remoteUrl().toDisplayString()
+                        << "]";
     if (f == _currentSyncFolder) {
         _lastSyncFolder = _currentSyncFolder;
         _currentSyncFolder = nullptr;
@@ -987,7 +1028,7 @@ Folder *FolderMan::addFolder(AccountState *accountState, const FolderDefinition
     // Migration: The first account that's configured for a local folder shall
     // be saved in a backwards-compatible way.
     bool oneAccountOnly = true;
-    foreach (Folder *other, FolderMan::instance()->map()) {
+    for (auto *other : map()) {
         if (other != folder && other->cleanPath() == folder->cleanPath()) {
             oneAccountOnly = false;
             break;
@@ -1049,7 +1090,7 @@ Folder *FolderMan::folderForPath(const QString &path, QString *relativePath)
 {
     QString absolutePath = QDir::cleanPath(path) + QLatin1Char('/');
 
-    foreach (Folder *folder, this->map().values()) {
+    for (auto *folder : map()) {
         const QString folderPath = folder->cleanPath() + QLatin1Char('/');
 
         if (absolutePath.startsWith(folderPath, (Utility::isWindows() || Utility::isMac()) ? Qt::CaseInsensitive : Qt::CaseSensitive)) {
@@ -1075,7 +1116,7 @@ QStringList FolderMan::findFileInLocalFolders(const QString &relPath, const Acco
     if (!serverPath.startsWith('/'))
         serverPath.prepend('/');
 
-    foreach (Folder *folder, this->map().values()) {
+    for (auto *folder : map()) {
         if (acc != nullptr && folder->accountState()->account() != acc) {
             continue;
         }
@@ -1124,13 +1165,13 @@ void FolderMan::removeFolder(Folder *f)
         // Let the folder delete itself when done.
         connect(f, &Folder::syncFinished, f, &QObject::deleteLater);
     } else {
-        delete f;
+        f->deleteLater();
     }
 
 #ifdef Q_OS_WIN
     _navigationPaneHelper.scheduleUpdateCloudStorageRegistry();
 #endif
-
+    Q_EMIT folderRemoved(f);
     emit folderListChanged(_folderMap);
 }
 
@@ -1208,7 +1249,7 @@ bool FolderMan::startFromScratch(const QString &localFolder)
 
 void FolderMan::setDirtyProxy()
 {
-    foreach (Folder *f, _folderMap.values()) {
+    for (auto *f : qAsConst(_folderMap)) {
         if (f) {
             if (f->accountState() && f->accountState()->account()
                 && f->accountState()->account()->networkAccessManager()) {
@@ -1222,7 +1263,7 @@ void FolderMan::setDirtyProxy()
 
 void FolderMan::setDirtyNetworkLimits()
 {
-    foreach (Folder *f, _folderMap.values()) {
+    for (auto *f : qAsConst(_folderMap)) {
         // set only in busy folders. Otherwise they read the config anyway.
         if (f && f->isBusy()) {
             f->setDirtyNetworkLimits();
@@ -1230,100 +1271,24 @@ void FolderMan::setDirtyNetworkLimits()
     }
 }
 
-void FolderMan::trayOverallStatus(const QList<Folder *> &folders,
-    SyncResult::Status *status, bool *unresolvedConflicts)
+TrayOverallStatusResult FolderMan::trayOverallStatus(const QList<Folder *> &folders)
 {
-    *status = SyncResult::Undefined;
-    *unresolvedConflicts = false;
+    TrayOverallStatusResult result;
 
-    int cnt = folders.count();
-
-    // if one folder: show the state of the one folder.
-    // if more folders:
     // if one of them has an error -> show error
     // if one is paused, but others ok, show ok
-    // do not show "problem" in the tray
     //
-    if (cnt == 1) {
-        Folder *folder = folders.at(0);
-        if (folder) {
-            auto syncResult = folder->syncResult();
-            if (folder->syncPaused()) {
-                *status = SyncResult::Paused;
-            } else {
-                SyncResult::Status syncStatus = syncResult.status();
-                switch (syncStatus) {
-                case SyncResult::Undefined:
-                    *status = SyncResult::Error;
-                    break;
-                case SyncResult::Problem: // don't show the problem icon in tray.
-                    *status = SyncResult::Success;
-                    break;
-                default:
-                    *status = syncStatus;
-                    break;
-                }
-            }
-            *unresolvedConflicts = syncResult.hasUnresolvedConflicts();
-        }
-    } else {
-        int errorsSeen = 0;
-        int goodSeen = 0;
-        int abortOrPausedSeen = 0;
-        int runSeen = 0;
-        int various = 0;
-
-        foreach (Folder *folder, folders) {
-            SyncResult folderResult = folder->syncResult();
-            if (folder->syncPaused()) {
-                abortOrPausedSeen++;
-            } else {
-                SyncResult::Status syncStatus = folderResult.status();
-
-                switch (syncStatus) {
-                case SyncResult::Undefined:
-                case SyncResult::NotYetStarted:
-                    various++;
-                    break;
-                case SyncResult::SyncPrepare:
-                case SyncResult::SyncRunning:
-                    runSeen++;
-                    break;
-                case SyncResult::Problem: // don't show the problem icon in tray.
-                case SyncResult::Success:
-                    goodSeen++;
-                    break;
-                case SyncResult::Error:
-                case SyncResult::SetupError:
-                    errorsSeen++;
-                    break;
-                case SyncResult::SyncAbortRequested:
-                case SyncResult::Paused:
-                    abortOrPausedSeen++;
-                    // no default case on purpose, check compiler warnings
-                }
-            }
-            if (folderResult.hasUnresolvedConflicts())
-                *unresolvedConflicts = true;
-        }
-        if (errorsSeen > 0) {
-            *status = SyncResult::Error;
-        } else if (abortOrPausedSeen > 0 && abortOrPausedSeen == cnt) {
-            // only if all folders are paused
-            *status = SyncResult::Paused;
-        } else if (runSeen > 0) {
-            *status = SyncResult::SyncRunning;
-        } else if (goodSeen > 0) {
-            *status = SyncResult::Success;
-        }
+    for (auto *folder : folders) {
+        result.addResult(folder);
     }
+    return result;
 }
 
 QString FolderMan::trayTooltipStatusString(
-    SyncResult::Status syncStatus, bool hasUnresolvedConflicts, bool paused)
+    const SyncResult &result, bool paused)
 {
     QString folderMessage;
-    switch (syncStatus) {
+    switch (result.status()) {
     case SyncResult::Undefined:
         folderMessage = tr("Undefined State.");
         break;
@@ -1338,7 +1303,7 @@ QString FolderMan::trayTooltipStatusString(
         break;
     case SyncResult::Success:
     case SyncResult::Problem:
-        if (hasUnresolvedConflicts) {
+        if (result.hasUnresolvedConflicts()) {
             folderMessage = tr("Sync was successful, unresolved conflicts.");
         } else {
             folderMessage = tr("Last Sync was successful.");
@@ -1374,9 +1339,12 @@ static QString checkPathValidityRecursive(const QString &path)
     Utility::NtfsPermissionLookupRAII ntfs_perm;
 #endif
     const QFileInfo selFile(path);
+    if (numberOfSyncJournals(selFile.filePath()) != 0) {
+        return FolderMan::tr("The folder %1 is used in a folder sync connection!").arg(QDir::toNativeSeparators(selFile.filePath()));
+    }
 
     if (!selFile.exists()) {
-        QString parentPath = selFile.dir().path();
+        const QString parentPath = selFile.path();
         if (parentPath != path)
             return checkPathValidityRecursive(parentPath);
         return FolderMan::tr("The selected path does not exist!");
@@ -1413,57 +1381,40 @@ static QString canonicalPath(const QString &path)
     return selFile.canonicalFilePath();
 }
 
-QString FolderMan::checkPathValidityForNewFolder(const QString &path, const QUrl &serverUrl) const
+QString FolderMan::checkPathValidityForNewFolder(const QString &path) const
 {
-    QString recursiveValidity = checkPathValidityRecursive(path);
-    if (!recursiveValidity.isEmpty()) {
-        qCDebug(lcFolderMan) << path << recursiveValidity;
-        return recursiveValidity;
-    }
-
     // check if the local directory isn't used yet in another ownCloud sync
-    Qt::CaseSensitivity cs = Qt::CaseSensitive;
-    if (Utility::fsCasePreserving()) {
-        cs = Qt::CaseInsensitive;
-    }
+    const auto cs = Utility::fsCaseSensitivity();
 
     const QString userDir = QDir::cleanPath(canonicalPath(path)) + '/';
     for (auto i = _folderMap.constBegin(); i != _folderMap.constEnd(); ++i) {
         Folder *f = static_cast<Folder *>(i.value());
-        QString folderDir = QDir::cleanPath(canonicalPath(f->path())) + '/';
+        const QString folderDir = QDir::cleanPath(canonicalPath(f->path())) + '/';
 
-        bool differentPaths = QString::compare(folderDir, userDir, cs) != 0;
-        if (differentPaths && folderDir.startsWith(userDir, cs)) {
+        if (QString::compare(folderDir, userDir, cs) == 0) {
+            return tr("There is already a sync from the server to this local folder. "
+                      "Please pick another local folder!");
+        }
+        if (FileSystem::isChildPathOf(folderDir, userDir)) {
             return tr("The local folder %1 already contains a folder used in a folder sync connection. "
                       "Please pick another one!")
                 .arg(QDir::toNativeSeparators(path));
         }
 
-        if (differentPaths && userDir.startsWith(folderDir, cs)) {
+        if (FileSystem::isChildPathOf(userDir, folderDir)) {
             return tr("The local folder %1 is already contained in a folder used in a folder sync connection. "
                       "Please pick another one!")
                 .arg(QDir::toNativeSeparators(path));
         }
-
-        // if both pathes are equal, the server url needs to be different
-        // otherwise it would mean that a new connection from the same local folder
-        // to the same account is added which is not wanted. The account must differ.
-        if (serverUrl.isValid() && !differentPaths) {
-            QUrl folderUrl = f->accountState()->account()->url();
-            QString user = f->accountState()->account()->credentials()->user();
-            folderUrl.setUserName(user);
-
-            if (serverUrl == folderUrl) {
-                return tr("There is already a sync from the server to this local folder. "
-                          "Please pick another local folder!");
-            }
-        }
     }
-
-    return QString();
+    const auto result = checkPathValidityRecursive(path);
+    if (!result.isEmpty()) {
+        return tr("%1 Please pick another one!").arg(result);
+    }
+    return {};
 }
 
-QString FolderMan::findGoodPathForNewSyncFolder(const QString &basePath, const QUrl &serverUrl) const
+QString FolderMan::findGoodPathForNewSyncFolder(const QString &basePath) const
 {
     QString folder = basePath;
 
@@ -1471,32 +1422,21 @@ QString FolderMan::findGoodPathForNewSyncFolder(const QString &basePath, const Q
     // possibly find a valid sync folder inside it.
     // Example: Someone syncs their home directory. Then ~/foobar is not
     // going to be an acceptable sync folder path for any value of foobar.
-    QString parentFolder = QFileInfo(folder).dir().canonicalPath();
+    const QString parentFolder = QFileInfo(folder).canonicalPath();
     if (FolderMan::instance()->folderForPath(parentFolder)) {
         // Any path with that parent is going to be unacceptable,
         // so just keep it as-is.
         return basePath;
     }
-
-    int attempt = 1;
-    forever {
-        const bool isGood =
-            !QFileInfo(folder).exists()
-            && FolderMan::instance()->checkPathValidityForNewFolder(folder, serverUrl).isEmpty();
-        if (isGood) {
-            break;
+    // Count attempts and give up eventually
+    for (int attempt = 2; attempt < 100; ++attempt) {
+        if (!QFileInfo::exists(folder)
+            && FolderMan::instance()->checkPathValidityForNewFolder(folder).isEmpty()) {
+            return folder;
         }
-
-        // Count attempts and give up eventually
-        attempt++;
-        if (attempt > 100) {
-            return basePath;
-        }
-
         folder = basePath + QString::number(attempt);
     }
-
-    return folder;
+    return basePath;
 }
 
 bool FolderMan::ignoreHiddenFiles() const
@@ -1511,7 +1451,7 @@ void FolderMan::setIgnoreHiddenFiles(bool ignore)
 {
     // Note that the setting will revert to 'true' if all folders
     // are deleted...
-    foreach (Folder *folder, _folderMap) {
+    for (auto *folder : qAsConst(_folderMap)) {
         folder->setIgnoreHiddenFiles(ignore);
         folder->saveToSettings();
     }
@@ -1542,4 +1482,20 @@ void FolderMan::restartApplication()
     }
 }
 
+Result<void, QString> FolderMan::unsupportedConfiguration(const QString &path) const
+{
+    if (numberOfSyncJournals(path) > 1) {
+        return tr("Multiple accounts are sharing the folder %1.\n"
+                  "This configuration is know to lead to dataloss and is no longer supported.\n"
+                  "Please consider removing this folder from the account and adding it again.")
+            .arg(path);
+    }
+    return {};
+}
+
+bool FolderMan::checkVfsAvailability(const QString &path) const
+{
+    return unsupportedConfiguration(path) && Vfs::checkAvailability(path);
+}
+
 } // namespace OCC
