@@ -122,10 +122,6 @@ void SelectiveSyncWidget::refreshFolders()
 void SelectiveSyncWidget::setFolderInfo(const QString &folderPath, const QString &rootName, const QStringList &oldBlackList)
 {
     _folderPath = folderPath;
-    if (_folderPath.startsWith(QLatin1Char('/'))) {
-        // remove leading '/'
-        _folderPath = folderPath.mid(1);
-    }
     _rootName = rootName;
     _oldBlackList = oldBlackList;
     refreshFolders();
@@ -159,7 +155,7 @@ void SelectiveSyncWidget::recursiveInsert(QTreeWidgetItem *parent, QStringList p
             if (parent->checkState(0) == Qt::Checked
                 || parent->checkState(0) == Qt::PartiallyChecked) {
                 item->setCheckState(0, Qt::Checked);
-                foreach (const QString &str, _oldBlackList) {
+                for (const auto &str : qAsConst(_oldBlackList)) {
                     if (str == path || str == QLatin1String("/")) {
                         item->setCheckState(0, Qt::Unchecked);
                         break;
@@ -188,33 +184,23 @@ void SelectiveSyncWidget::recursiveInsert(QTreeWidgetItem *parent, QStringList p
 void SelectiveSyncWidget::slotUpdateDirectories(QStringList list)
 {
     auto job = qobject_cast<LsColJob *>(sender());
-    QScopedValueRollback<bool> isInserting(_inserting);
-    _inserting = true;
+    QScopedValueRollback<bool> isInserting(_inserting, true);
 
     SelectiveSyncTreeViewItem *root = static_cast<SelectiveSyncTreeViewItem *>(_folderTree->topLevelItem(0));
 
-    QUrl url = _account->davUrl();
-    QString pathToRemove = url.path();
-    if (!pathToRemove.endsWith('/')) {
-        pathToRemove.append('/');
-    }
-    pathToRemove.append(_folderPath);
-    if (!_folderPath.isEmpty())
-        pathToRemove.append('/');
+    const QString pathToRemove = Utility::concatUrlPath(_account->davUrl(), _folderPath).path();
 
     // Check for excludes.
-    QMutableListIterator<QString> it(list);
-    while (it.hasNext()) {
-        it.next();
-        if (_excludedFiles.isExcluded(it.value(), pathToRemove, FolderMan::instance()->ignoreHiddenFiles()))
-            it.remove();
-    }
+    list.erase(std::remove_if(list.begin(), list.end(), [&pathToRemove, this](const QString &it) {
+        return _excludedFiles.isExcludedRemote(it, pathToRemove, FolderMan::instance()->ignoreHiddenFiles(), ItemTypeDirectory);
+    }),
+        list.end());
 
     // Since / cannot be in the blacklist, expand it to the actual
     // list of top-level folders as soon as possible.
     if (_oldBlackList == QStringList("/")) {
         _oldBlackList.clear();
-        foreach (QString path, list) {
+        for (auto path : qAsConst(list)) {
             path.remove(pathToRemove);
             if (path.isEmpty()) {
                 continue;
@@ -237,7 +223,7 @@ void SelectiveSyncWidget::slotUpdateDirectories(QStringList list)
         root->setIcon(0, Theme::instance()->applicationIcon());
         root->setData(0, Qt::UserRole, QString());
         root->setCheckState(0, Qt::Checked);
-        qint64 size = job ? job->_sizes.value(pathToRemove, -1) : -1;
+        qint64 size = job ? job->sizes().value(pathToRemove, -1) : -1;
         if (size >= 0) {
             root->setText(1, Utility::octetsToString(size));
             root->setData(1, Qt::UserRole, size);
@@ -245,8 +231,8 @@ void SelectiveSyncWidget::slotUpdateDirectories(QStringList list)
     }
 
     Utility::sortFilenames(list);
-    foreach (QString path, list) {
-        auto size = job ? job->_sizes.value(path) : 0;
+    for (auto path : qAsConst(list)) {
+        auto size = job ? job->sizes().value(path) : 0;
         path.remove(pathToRemove);
         QStringList paths = path.split('/');
         if (paths.last().isEmpty())
@@ -286,11 +272,7 @@ void SelectiveSyncWidget::slotItemExpanded(QTreeWidgetItem *item)
     QString dir = item->data(0, Qt::UserRole).toString();
     if (dir.isEmpty())
         return;
-    QString prefix;
-    if (!_folderPath.isEmpty()) {
-        prefix = _folderPath + QLatin1Char('/');
-    }
-    LsColJob *job = new LsColJob(_account, prefix + dir, this);
+    LsColJob *job = new LsColJob(_account, _folderPath + dir, this);
     job->setProperties(QList<QByteArray>() << "resourcetype"
                                            << "http://owncloud.org/ns:size");
     connect(job, &LsColJob::directoryListingSubfolders,
@@ -381,7 +363,7 @@ QStringList SelectiveSyncWidget::createBlackList(QTreeWidgetItem *root) const
     } else {
         // We did not load from the server so we re-use the one from the old black list
         QString path = root->data(0, Qt::UserRole).toString();
-        foreach (const QString &it, _oldBlackList) {
+        for (const auto &it : _oldBlackList) {
             if (it.startsWith(path))
                 result += it;
         }
@@ -488,8 +470,8 @@ void SelectiveSyncDialog::accept()
         //The part that changed should not be read from the DB on next sync because there might be new folders
         // (the ones that are no longer in the blacklist)
         auto blackListSet = blackList.toSet();
-        auto changes = (oldBlackListSet - blackListSet) + (blackListSet - oldBlackListSet);
-        foreach (const auto &it, changes) {
+        const auto changes = (oldBlackListSet - blackListSet) + (blackListSet - oldBlackListSet);
+        for (const auto &it : changes) {
             _folder->journalDb()->schedulePathForRemoteDiscovery(it);
             _folder->schedulePathForLocalDiscovery(it);
         }
