@@ -40,7 +40,6 @@
 #include <QOperatingSystemVersion>
 #include <QStandardPaths>
 
-#define DEFAULT_REMOTE_POLL_INTERVAL 30000 // default remote poll time in milliseconds
 #define DEFAULT_MAX_LOG_LINES 20000
 
 namespace OCC {
@@ -63,6 +62,7 @@ const QString showInExplorerNavigationPaneC() { return QStringLiteral("showInExp
 const QString skipUpdateCheckC() { return QStringLiteral("skipUpdateCheck"); }
 const QString updateCheckIntervalC() { return QStringLiteral("updateCheckInterval"); }
 const QString updateChannelC() { return QStringLiteral("updateChannel"); }
+const QString uiLanguageC() { return QStringLiteral("uiLanguage"); }
 const QString geometryC() { return QStringLiteral("geometry"); }
 const QString timeoutC() { return QStringLiteral("timeout"); }
 const QString chunkSizeC() { return QStringLiteral("chunkSize"); }
@@ -90,13 +90,10 @@ const QString newBigFolderSizeLimitC() { return QStringLiteral("newBigFolderSize
 const QString useNewBigFolderSizeLimitC() { return QStringLiteral("useNewBigFolderSizeLimit"); }
 const QString confirmExternalStorageC() { return QStringLiteral("confirmExternalStorage"); }
 const QString moveToTrashC() { return QStringLiteral("moveToTrash"); }
-
-const QString certPath() { return QStringLiteral("http_certificatePath"); }
-const QString certPasswd() { return QStringLiteral("http_certificatePasswd"); }
 }
 
 QString ConfigFile::_confDir = QString();
-bool ConfigFile::_askedUser = false;
+const std::chrono::seconds DefaultRemotePollInterval { 30 }; // default remote poll time in milliseconds
 
 static chrono::milliseconds millisecondsValue(const QSettings &setting, const QString &key,
     chrono::milliseconds defaultValue)
@@ -106,15 +103,10 @@ static chrono::milliseconds millisecondsValue(const QSettings &setting, const QS
 
 ConfigFile::ConfigFile()
 {
-    // QDesktopServices uses the application name to create a config path
-    // TODO: we use multiple calls to setApplicationName with different arguments...
-    qApp->setApplicationName(Theme::instance()->appNameGUI());
-
     QSettings::setDefaultFormat(QSettings::IniFormat);
 
     const QString config = configFile();
 
-
     QSettings settings(config, QSettings::IniFormat);
     settings.beginGroup(defaultConnection());
 
@@ -268,7 +260,7 @@ QVariant ConfigFile::getPolicySetting(const QString &setting, const QVariant &de
     return defaultValue;
 }
 
-QString ConfigFile::configPath() const
+QString ConfigFile::configPath()
 {
     if (_confDir.isEmpty()) {
         // On Unix, use the AppConfigLocation for the settings, that's configurable with the XDG_CONFIG_HOME env variable.
@@ -355,11 +347,9 @@ QString ConfigFile::backup() const
     auto versionString = clientVersionString();
     if (!versionString.isEmpty())
         versionString.prepend(QLatin1Char('_'));
-    QString backupFile =
+    const QString backupFile =
         QStringLiteral("%1.backup_%2%3")
-            .arg(baseFile)
-            .arg(QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_HHmmss")))
-            .arg(versionString);
+            .arg(baseFile, QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_HHmmss")), versionString);
 
     // If this exact file already exists it's most likely that a backup was
     // already done. (two backup calls directly after each other, potentially
@@ -371,15 +361,14 @@ QString ConfigFile::backup() const
     return backupFile;
 }
 
-QString ConfigFile::configFile() const
+QString ConfigFile::configFile()
 {
     return configPath() + Theme::instance()->configFileName();
 }
 
 bool ConfigFile::exists()
 {
-    QFile file(configFile());
-    return file.exists();
+    return QFileInfo::exists(configFile());
 }
 
 QString ConfigFile::defaultConnection() const
@@ -397,15 +386,6 @@ void ConfigFile::storeData(const QString &group, const QString &key, const QVari
     settings.sync();
 }
 
-QVariant ConfigFile::retrieveData(const QString &group, const QString &key) const
-{
-    const QString con(group.isEmpty() ? defaultConnection() : group);
-    QSettings settings(configFile(), QSettings::IniFormat);
-
-    settings.beginGroup(con);
-    return settings.value(key);
-}
-
 void ConfigFile::removeData(const QString &group, const QString &key)
 {
     const QString con(group.isEmpty() ? defaultConnection() : group);
@@ -424,7 +404,7 @@ bool ConfigFile::dataExists(const QString &group, const QString &key) const
     return settings.contains(key);
 }
 
-chrono::milliseconds ConfigFile::remotePollInterval(const QString &connection) const
+chrono::milliseconds ConfigFile::remotePollInterval(std::chrono::seconds defaultVal, const QString &connection) const
 {
     QString con(connection);
     if (connection.isEmpty())
@@ -433,11 +413,18 @@ chrono::milliseconds ConfigFile::remotePollInterval(const QString &connection) c
     QSettings settings(configFile(), QSettings::IniFormat);
     settings.beginGroup(con);
 
-    auto defaultPollInterval = chrono::milliseconds(DEFAULT_REMOTE_POLL_INTERVAL);
+    auto defaultPollInterval { DefaultRemotePollInterval };
+
+    // The server default-capabilities is set to 60, which is, if interpreted in milliseconds,
+    // pretty small. If the value is above 5 seconds, it was set intentionally.
+    // Server admins have to set the value in Milliseconds!
+    if (defaultVal > chrono::seconds(5)) {
+        defaultPollInterval = defaultVal;
+    }
     auto remoteInterval = millisecondsValue(settings, remotePollIntervalC(), defaultPollInterval);
     if (remoteInterval < chrono::seconds(5)) {
-        qCWarning(lcConfigFile) << "Remote Interval is less than 5 seconds, reverting to" << DEFAULT_REMOTE_POLL_INTERVAL;
         remoteInterval = defaultPollInterval;
+        qCWarning(lcConfigFile) << "Remote Interval is less than 5 seconds, reverting to" << remoteInterval.count();
     }
     return remoteInterval;
 }
@@ -458,9 +445,9 @@ void ConfigFile::setRemotePollInterval(chrono::milliseconds interval, const QStr
     settings.sync();
 }
 
-chrono::milliseconds ConfigFile::forceSyncInterval(const QString &connection) const
+chrono::milliseconds ConfigFile::forceSyncInterval(std::chrono::seconds remoteFromCapabilities, const QString &connection) const
 {
-    auto pollInterval = remotePollInterval(connection);
+    auto pollInterval = remotePollInterval(remoteFromCapabilities, connection);
 
     QString con(connection);
     if (connection.isEmpty())
@@ -568,6 +555,18 @@ void ConfigFile::setUpdateChannel(const QString &channel)
     settings.setValue(updateChannelC(), channel);
 }
 
+QString ConfigFile::uiLanguage() const
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    return settings.value(uiLanguageC(), QString()).toString();
+}
+
+void ConfigFile::setUiLanguage(const QString &uiLanguage)
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    settings.setValue(uiLanguageC(), uiLanguage);
+}
+
 void ConfigFile::setProxyType(int proxyType,
     const QString &host,
     int port, bool needsAuth,
@@ -835,30 +834,6 @@ bool ConfigFile::showExperimentalOptions() const
     return settings.value(showExperimentalOptionsC(), false).toBool();
 }
 
-QString ConfigFile::certificatePath() const
-{
-    return retrieveData(QString(), certPath()).toString();
-}
-
-void ConfigFile::setCertificatePath(const QString &cPath)
-{
-    QSettings settings(configFile(), QSettings::IniFormat);
-    settings.setValue(certPath(), cPath);
-    settings.sync();
-}
-
-QString ConfigFile::certificatePasswd() const
-{
-    return retrieveData(QString(), certPasswd()).toString();
-}
-
-void ConfigFile::setCertificatePasswd(const QString &cPasswd)
-{
-    QSettings settings(configFile(), QSettings::IniFormat);
-    settings.setValue(certPasswd(), cPasswd);
-    settings.sync();
-}
-
 QString ConfigFile::clientVersionString() const
 {
     QSettings settings(configFile(), QSettings::IniFormat);
@@ -871,16 +846,9 @@ void ConfigFile::setClientVersionString(const QString &version)
     settings.setValue(clientVersionC(), version);
 }
 
-Q_GLOBAL_STATIC(QString, g_configFileName)
-
 std::unique_ptr<QSettings> ConfigFile::settingsWithGroup(const QString &group, QObject *parent)
 {
-    if (g_configFileName()->isEmpty()) {
-        // cache file name
-        ConfigFile cfg;
-        *g_configFileName() = cfg.configFile();
-    }
-    std::unique_ptr<QSettings> settings(new QSettings(*g_configFileName(), QSettings::IniFormat, parent));
+    std::unique_ptr<QSettings> settings(new QSettings(ConfigFile::configFile(), QSettings::IniFormat, parent));
     settings->beginGroup(group);
     return settings;
 }
