@@ -28,6 +28,7 @@
 #include <QFileInfo>
 #include <QTextCodec>
 #include <cstring>
+#include <QDateTime>
 
 
 namespace OCC {
@@ -37,8 +38,6 @@ Q_LOGGING_CATEGORY(lcDiscovery, "sync.discovery", QtInfoMsg)
 /* Given a sorted list of paths ending with '/', return whether or not the given path is within one of the paths of the list*/
 static bool findPathInList(const QStringList &list, const QString &path)
 {
-    Q_ASSERT(std::is_sorted(list.begin(), list.end()));
-
     if (list.size() == 1 && list.first() == QLatin1String("/")) {
         // Special case for the case "/" is there, it matches everything
         return true;
@@ -114,7 +113,7 @@ void DiscoveryPhase::checkSelectiveSyncNewFolder(const QString &path, RemotePerm
                                                    << "http://owncloud.org/ns:size");
     QObject::connect(propfindJob, &PropfindJob::finishedWithError,
         this, [=] { return callback(false); });
-    QObject::connect(propfindJob, &PropfindJob::result, this, [=](const QVariantMap &values) {
+    QObject::connect(propfindJob, &PropfindJob::result, this, [=](const QMap<QString, QString> &values) {
         auto result = values.value(QStringLiteral("size")).toLongLong();
         if (result >= limit) {
             // we tell the UI there is a new folder
@@ -159,34 +158,40 @@ QPair<bool, QByteArray> DiscoveryPhase::findAndCancelDeletedJob(const QString &o
     QByteArray oldEtag;
     auto it = _deletedItem.find(originalPath);
     if (it != _deletedItem.end()) {
-        const SyncInstructions instruction = (*it)->_instruction;
-        if (instruction == CSYNC_INSTRUCTION_IGNORE && (*it)->_type == ItemTypeVirtualFile) {
+        const auto &item = *it;
+        const SyncInstructions instruction = item->_instruction;
+        if (instruction == CSYNC_INSTRUCTION_IGNORE && item->_type == ItemTypeVirtualFile) {
             // re-creation of virtual files count as a delete
+            // restoration after a prohibited move
             // a file might be in an error state and thus gets marked as CSYNC_INSTRUCTION_IGNORE
             // after it was initially marked as CSYNC_INSTRUCTION_REMOVE
             // return true, to not trigger any additional actions on that file that could elad to dataloss
             result = true;
-            oldEtag = (*it)->_etag;
+            oldEtag = item->_etag;
         } else {
             if (!(instruction == CSYNC_INSTRUCTION_REMOVE
                     // re-creation of virtual files count as a delete
-                    || ((*it)->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW)
-                    || ((*it)->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW)))
-            {
+                    || (item->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW)
+                    || (item->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW)
+                    // we encountered an ignored error
+                    || (item->_hasBlacklistEntry && instruction == CSYNC_INSTRUCTION_IGNORE))) {
                 qCWarning(lcDiscovery) << "OC_ENFORCE(FAILING)" << originalPath;
                 qCWarning(lcDiscovery) << "instruction == CSYNC_INSTRUCTION_REMOVE" << (instruction == CSYNC_INSTRUCTION_REMOVE);
-                qCWarning(lcDiscovery) << "((*it)->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW)"
-                                       << ((*it)->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW);
-                qCWarning(lcDiscovery) << "((*it)->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW))"
-                                       << ((*it)->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW);
+                qCWarning(lcDiscovery) << "(item->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW)"
+                                       << (item->_type == ItemTypeVirtualFile && instruction == CSYNC_INSTRUCTION_NEW);
+                qCWarning(lcDiscovery) << "(item->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW)"
+                                       << (item->_isRestoration && instruction == CSYNC_INSTRUCTION_NEW);
+                qCWarning(lcDiscovery) << "(item->_hasBlacklistEntry && instruction == CSYNC_INSTRUCTION_IGNORE)"
+                                       << (item->_hasBlacklistEntry && instruction == CSYNC_INSTRUCTION_IGNORE);
                 qCWarning(lcDiscovery) << "instruction" << instruction;
-                qCWarning(lcDiscovery) << "(*it)->_type" << (*it)->_type;
-                qCWarning(lcDiscovery) << "(*it)->_isRestoration " << (*it)->_isRestoration;
+                qCWarning(lcDiscovery) << "item->_type" << item->_type;
+                qCWarning(lcDiscovery) << "item->_isRestoration " << item->_isRestoration;
+                qCWarning(lcDiscovery) << "item->_remotePerm" << item->_remotePerm;
                 OC_ENFORCE(false);
             }
-            (*it)->_instruction = CSYNC_INSTRUCTION_NONE;
+            item->_instruction = CSYNC_INSTRUCTION_NONE;
             result = true;
-            oldEtag = (*it)->_etag;
+            oldEtag = item->_etag;
         }
         _deletedItem.erase(it);
     }
@@ -383,7 +388,9 @@ static void propertyMapToRemoteInfo(const QMap<QString, QString> &map, RemoteInf
         if (property == QLatin1String("resourcetype")) {
             result.isDirectory = value.contains(QLatin1String("collection"));
         } else if (property == QLatin1String("getlastmodified")) {
-            result.modtime = oc_httpdate_parse(value.toUtf8().constData());
+            const auto date = QDateTime::fromString(value, Qt::RFC2822Date);
+            Q_ASSERT(date.isValid());
+            result.modtime = date.toTime_t();
         } else if (property == QLatin1String("getcontentlength")) {
             // See #4573, sometimes negative size values are returned
             bool ok = false;
@@ -461,7 +468,7 @@ void DiscoverySingleDirectoryJob::directoryListingIteratedSlot(const QString &fi
     //This works in concerto with the RequestEtagJob and the Folder object to check if the remote folder changed.
     if (map.contains(QStringLiteral("getetag"))) {
         if (_firstEtag.isEmpty()) {
-            _firstEtag = QString::fromUtf8(parseEtag(map.value(QStringLiteral("getetag")).toUtf8())); // for directory itself
+            _firstEtag = parseEtag(map.value(QStringLiteral("getetag")).toUtf8()); // for directory itself
         }
     }
 }
@@ -479,7 +486,7 @@ void DiscoverySingleDirectoryJob::lsJobFinishedWithoutErrorSlot()
         deleteLater();
         return;
     }
-    emit etag(_firstEtag);
+    emit etag(_firstEtag, QDateTime::fromString(QString::fromUtf8(_lsColJob->responseTimestamp()), Qt::RFC2822Date));
     emit finished(_results);
     deleteLater();
 }
