@@ -105,7 +105,7 @@ void GETFileJob::start()
     }
 
     QNetworkRequest req;
-    for (QMap<QByteArray, QByteArray>::const_iterator it = _headers.begin(); it != _headers.end(); ++it) {
+    for (auto it = _headers.cbegin(); it != _headers.cend(); ++it) {
         req.setRawHeader(it.key(), it.value());
     }
 
@@ -329,12 +329,12 @@ void GETFileJob::slotReadyRead()
 
 void GETJob::onTimedOut()
 {
-    qCWarning(lcGetJob) << "Timeout" << (reply() ? reply()->request().url().path() : path());
-    if (!reply())
-        return;
-    _errorString = tr("Connection Timeout");
-    _errorStatus = SyncFileItem::FatalError;
-    reply()->abort();
+    qCWarning(lcGetJob) << this << "timeout";
+    if (reply()) {
+        _errorString = tr("Connection Timeout");
+        _errorStatus = SyncFileItem::FatalError;
+    }
+    AbstractNetworkJob::onTimedOut();
 }
 
 QString GETJob::errorString() const
@@ -358,13 +358,17 @@ void PropagateDownloadFile::start()
 
     // For virtual files just dehydrate or create the file and be done
     if (_item->_type == ItemTypeVirtualFileDehydration) {
-        QString fsPath = propagator()->fullLocalPath(_item->_file);
+        const QString fsPath = propagator()->fullLocalPath(_item->_file);
         if (!FileSystem::verifyFileUnchanged(fsPath, _item->_previousSize, _item->_previousModtime)) {
             propagator()->_anotherSyncNeeded = true;
             done(SyncFileItem::SoftError, tr("File has changed since discovery"));
             return;
         }
-
+        if (FileSystem::isFileLocked(fsPath, FileSystem::LockMode::Exclusive)) {
+            Q_EMIT propagator()->seenLockedFile(fsPath, FileSystem::LockMode::Exclusive);
+            done(SyncFileItem::SoftError, tr("Failed to free up space, the file %1 is currently in use").arg(fsPath));
+            return;
+        }
         qCDebug(lcPropagateDownload) << "dehydrating file" << _item->_file;
         auto r = vfs->dehydratePlaceholder(*_item);
         if (!r) {
@@ -382,8 +386,8 @@ void PropagateDownloadFile::start()
     if (_item->_type == ItemTypeVirtualFile) {
         qCDebug(lcPropagateDownload) << "creating virtual file" << _item->_file;
         // do a klaas' case clash check.
-        if (propagator()->localFileNameClash(_item->_file)) {
-            done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash!").arg(QDir::toNativeSeparators(_item->_file)));
+        if (auto clash = propagator()->localFileNameClash(_item->_file)) {
+            done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash with %2!").arg(QDir::toNativeSeparators(_item->_file), QDir::toNativeSeparators(clash.get())));
             return;
         }
         auto r = vfs->createPlaceholder(*_item);
@@ -409,6 +413,12 @@ void PropagateDownloadFile::start()
     // Maybe it's not a real conflict and no download is necessary!
     // If the hashes are collision safe and identical, we assume the content is too.
     // For weak checksums, we only do that if the mtimes are also identical.
+
+    const auto csync_is_collision_safe_hash = [](const QByteArray &checksum_header)
+    {
+        return checksum_header.startsWith("SHA")
+            || checksum_header.startsWith("MD5:");
+    };
     if (_item->_instruction == CSYNC_INSTRUCTION_CONFLICT
         && _item->_size == _item->_previousSize
         && !_item->_checksumHeader.isEmpty()
@@ -454,11 +464,18 @@ void PropagateDownloadFile::startDownload()
         return;
 
     // do a klaas' case clash check.
-    if (propagator()->localFileNameClash(_item->_file)) {
-        done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash!").arg(QDir::toNativeSeparators(_item->_file)));
+    if (auto clash = propagator()->localFileNameClash(_item->_file)) {
+        done(SyncFileItem::NormalError, tr("File %1 can not be downloaded because of a local file name clash with %2!").arg(QDir::toNativeSeparators(_item->_file), QDir::toNativeSeparators(clash.get())));
+        return;
+    }
+    // If the file is locked, we want to retry this sync when it
+    // becomes available again
+    const auto targetFile = propagator()->fullLocalPath(_item->_file);
+    if (FileSystem::isFileLocked(targetFile, FileSystem::LockMode::Exclusive)) {
+        emit propagator()->seenLockedFile(targetFile, FileSystem::LockMode::Exclusive);
+        done(SyncFileItem::SoftError, tr("The file %1 is currently in use").arg(QDir::toNativeSeparators(_item->_file)));
         return;
     }
-
     propagator()->reportProgress(*_item, 0);
 
     QString tmpFileName;
@@ -882,12 +899,12 @@ void PropagateDownloadFile::contentChecksumComputed(const QByteArray &checksumTy
 void PropagateDownloadFile::downloadFinished()
 {
     OC_ASSERT(!_tmpFile.isOpen());
-    QString fn = propagator()->fullLocalPath(_item->_file);
+    QString fn = propagator()->fullLocalPath(_item->destination());
 
     // In case of file name clash, report an error
     // This can happen if another parallel download saved a clashing file.
-    if (propagator()->localFileNameClash(_item->_file)) {
-        done(SyncFileItem::NormalError, tr("File %1 cannot be saved because of a local file name clash!").arg(QDir::toNativeSeparators(_item->_file)));
+    if (auto clash = propagator()->localFileNameClash(_item->_file)) {
+        done(SyncFileItem::NormalError, tr("File %1 cannot be saved because of a local file name clash with %2!").arg(QDir::toNativeSeparators(_item->_file), QDir::toNativeSeparators(clash.get())));
         return;
     }
 
@@ -906,10 +923,13 @@ void PropagateDownloadFile::downloadFinished()
         preserveGroupOwnership(_tmpFile.fileName(), existingFile);
 
         // Make the file a hydrated placeholder if possible
-        const auto result = propagator()->syncOptions()._vfs->convertToPlaceholder(_tmpFile.fileName(), *_item, fn);
+        const auto result = propagator()->updatePlaceholder(*_item, _tmpFile.fileName(), fn);
         if (!result) {
             done(SyncFileItem::NormalError, result.error());
             return;
+        } else if (result.get() == Vfs::ConvertToPlaceholderResult::Locked) {
+            done(SyncFileItem::SoftError, tr("The file %1 is currently in use").arg(_item->_file));
+            return;
         }
     }
 
@@ -940,20 +960,20 @@ void PropagateDownloadFile::downloadFinished()
             return;
         }
     }
+    // If the file is locked, we want to retry this sync when it
+    // becomes available again
+    if (FileSystem::isFileLocked(fn, FileSystem::LockMode::Exclusive)) {
+        emit propagator()->seenLockedFile(fn, FileSystem::LockMode::Exclusive);
+        done(SyncFileItem::SoftError, tr("The file %1 is currently in use").arg(fn));
+        return;
+    }
 
     QString error;
     emit propagator()->touchedFile(fn);
     // The fileChanged() check is done above to generate better error messages.
     if (!FileSystem::uncheckedRenameReplace(_tmpFile.fileName(), fn, &error)) {
-        qCWarning(lcPropagateDownload) << QStringLiteral("Rename failed: %1 => %2").arg(_tmpFile.fileName()).arg(fn);
-        // If the file is locked, we want to retry this sync when it
-        // becomes available again, otherwise try again directly
-        if (FileSystem::isFileLocked(fn)) {
-            emit propagator()->seenLockedFile(fn);
-        } else {
-            propagator()->_anotherSyncNeeded = true;
-        }
-
+        qCWarning(lcPropagateDownload) << "Rename failed:" << _tmpFile.fileName() << "=>" << fn;
+        propagator()->_anotherSyncNeeded = true;
         done(SyncFileItem::SoftError, error);
         return;
     }
@@ -999,10 +1019,13 @@ void PropagateDownloadFile::downloadFinished()
 
 void PropagateDownloadFile::updateMetadata(bool isConflict)
 {
-    QString fn = propagator()->fullLocalPath(_item->_file);
-
-    if (!propagator()->updateMetadata(*_item)) {
-        done(SyncFileItem::FatalError, tr("Error writing metadata to the database"));
+    const QString fn = propagator()->fullLocalPath(_item->destination());
+    const auto result = propagator()->updateMetadata(*_item);
+    if (!result) {
+        done(SyncFileItem::FatalError, tr("Error updating metadata: %1").arg(result.error()));
+        return;
+    } else if (result.get() == Vfs::ConvertToPlaceholderResult::Locked) {
+        done(SyncFileItem::SoftError, tr("The file %1 is currently in use").arg(_item->_file));
         return;
     }
     propagator()->_journal->setDownloadInfo(_item->_file, SyncJournalDb::DownloadInfo());
