@@ -14,6 +14,7 @@
 
 #include "theme.h"
 #include "config.h"
+#include "common/depreaction.h"
 #include "common/utility.h"
 #include "version.h"
 #include "configfile.h"
@@ -30,11 +31,7 @@
 #include "owncloudtheme.h"
 
 #ifdef THEME_INCLUDE
-#define Mirall OCC // namespace hack to make old themes work
-#define QUOTEME(M) #M
-#define INCLUDE_FILE(M) QUOTEME(M)
-#include INCLUDE_FILE(THEME_INCLUDE)
-#undef Mirall
+#include THEME_INCLUDE
 #endif
 
 namespace {
@@ -322,6 +319,17 @@ QString Theme::overrideServerUrl() const
     return QString();
 }
 
+QString Theme::overrideServerUrlV2() const
+{
+    static const auto serverOverride = qEnvironmentVariable("OWNCLOUD_OVERRIDE_SERVER_URL");
+    if (serverOverride.isEmpty()) {
+        OC_DISABLE_DEPRECATED_WARNING
+        return overrideServerUrl();
+        OC_ENABLE_DEPRECATED_WARNING
+    }
+    return serverOverride;
+}
+
 QString Theme::forceConfigAuthType() const
 {
     return QString();
@@ -367,6 +375,11 @@ bool Theme::wizardHideExternalStorageConfirmationCheckbox() const
     return false;
 }
 
+bool Theme::wizardSkipAdvancedPage() const
+{
+    return false;
+}
+
 bool Theme::wizardHideFolderSizeLimitCheckbox() const
 {
     return false;
@@ -382,6 +395,8 @@ QString Theme::gitSHA1(VersionFormat format) const
     }
     const auto gitUrl = QStringLiteral("https://github.com/owncloud/client/commit/%1").arg(gitSha);
     switch (format) {
+    case Theme::VersionFormat::OneLiner:
+        Q_FALLTHROUGH();
     case Theme::VersionFormat::Plain:
         return gitShahSort;
     case Theme::VersionFormat::Url:
@@ -395,7 +410,19 @@ QString Theme::gitSHA1(VersionFormat format) const
 
 QString Theme::aboutVersions(Theme::VersionFormat format) const
 {
-    const QString br = format == Theme::VersionFormat::RichText ? QStringLiteral("<br>") : QStringLiteral("\n");
+    const QString br = [&format] {
+        switch (format) {
+        case Theme::VersionFormat::RichText:
+            return QStringLiteral("<br>");
+        case Theme::VersionFormat::Url:
+            Q_FALLTHROUGH();
+        case Theme::VersionFormat::Plain:
+            return QStringLiteral("\n");
+        case Theme::VersionFormat::OneLiner:
+            return QStringLiteral(" ");
+        }
+        Q_UNREACHABLE();
+    }();
     const QString qtVersion = QString::fromUtf8(qVersion());
     const QString qtVersionString = (QLatin1String(QT_VERSION_STR) == qtVersion ? qtVersion : QCoreApplication::translate("ownCloudTheme::qtVer", "%1 (Built against Qt %1)").arg(qtVersion, QStringLiteral(QT_VERSION_STR)));
     QString _version = version();
@@ -408,17 +435,18 @@ QString Theme::aboutVersions(Theme::VersionFormat format) const
     }
 #endif
     return QCoreApplication::translate("ownCloudTheme::aboutVersions()",
-        "%1 %2 %3 %4%8"
+        "%1 %2 %3%8"
         "%9"
-        "Libraries Qt %5, %6%8"
-        "Using virtual files plugin: %7%8")
+        "Libraries Qt %4, %5%8"
+        "Using virtual files plugin: %6%8"
+        "%7")
         .arg(appName(),
             _version,
-            QStringLiteral(__DATE__),
-            QStringLiteral(__TIME__),
+            QStringLiteral(__DATE__ " " __TIME__),
             qtVersionString,
             QSslSocket::sslLibraryVersionString(),
             Vfs::modeToString(bestAvailableVfsMode()),
+            QSysInfo::productType() % QLatin1Char('-') % QSysInfo::kernelVersion(),
             br,
             gitUrl);
 }
@@ -438,12 +466,12 @@ QString Theme::about() const
               "%5 and the %5 logo are registered trademarks of %4 in the "
               "United States, other countries, or both.</p>"
               "<p><small>%6</small></p>")
-            .arg(Utility::escape(version()),
-                 Utility::escape(QStringLiteral("https://" MIRALL_STRINGIFY(APPLICATION_DOMAIN))),
-                 Utility::escape(QStringLiteral(MIRALL_STRINGIFY(APPLICATION_DOMAIN))),
-                 Utility::escape(vendor),
-                 Utility::escape(appNameGUI()),
-                 aboutVersions(Theme::VersionFormat::RichText));
+        .arg(Utility::escape(version()),
+            Utility::escape(QStringLiteral("https://" APPLICATION_DOMAIN)),
+            Utility::escape(QStringLiteral(APPLICATION_DOMAIN)),
+            Utility::escape(vendor),
+            Utility::escape(appNameGUI()),
+            aboutVersions(Theme::VersionFormat::RichText));
 }
 
 bool Theme::aboutShowCopyright() const
@@ -452,68 +480,43 @@ bool Theme::aboutShowCopyright() const
 }
 
 #ifndef TOKEN_AUTH_ONLY
-QVariant Theme::customMedia(CustomMediaType type)
-{
-    QVariant re;
-    QString key;
-
-    switch (type) {
-    case oCSetupTop:
-        key = QStringLiteral("oCSetupTop");
-        break;
-    case oCSetupSide:
-        key = QStringLiteral("oCSetupSide");
-        break;
-    case oCSetupBottom:
-        key = QStringLiteral("oCSetupBottom");
-        break;
-    case oCSetupResultTop:
-        key = QStringLiteral("oCSetupResultTop");
-        break;
-    }
-
-    QString imgPath = QStringLiteral(":/client/%1/theme/colored/%2.png").arg(appName(), key);
-    if (QFile::exists(imgPath)) {
-        QPixmap pix(imgPath);
-        if (pix.isNull()) {
-            // pixmap loading hasn't succeeded. We take the text instead.
-            re.setValue(key);
-        } else {
-            re.setValue(pix);
-        }
-    }
-    return re;
-}
-
 QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray, bool sysTrayMenuVisible) const
 {
-    // FIXME: Mind the size!
+    return syncStateIcon(SyncResult { status }, sysTray, sysTrayMenuVisible);
+}
+QIcon Theme::syncStateIcon(const SyncResult &result, bool sysTray, bool sysTrayMenuVisible) const
+{
     QString statusIcon;
 
-    switch (status) {
-    case SyncResult::Undefined:
-        // this can happen if no sync connections are configured.
-        statusIcon = QStringLiteral("state-information");
-        break;
+    switch (result.status()) {
     case SyncResult::NotYetStarted:
+        Q_FALLTHROUGH();
     case SyncResult::SyncRunning:
         statusIcon = QStringLiteral("state-sync");
         break;
     case SyncResult::SyncAbortRequested:
+        Q_FALLTHROUGH();
     case SyncResult::Paused:
         statusIcon = QStringLiteral("state-pause");
         break;
     case SyncResult::SyncPrepare:
+        Q_FALLTHROUGH();
     case SyncResult::Success:
+        if (result.hasUnresolvedConflicts()) {
+            return syncStateIcon(SyncResult { SyncResult::Problem }, sysTray, sysTrayMenuVisible);
+        }
         statusIcon = QStringLiteral("state-ok");
         break;
     case SyncResult::Problem:
+        Q_FALLTHROUGH();
+    case SyncResult::Undefined:
+        // this can happen if no sync connections are configured.
         statusIcon = QStringLiteral("state-information");
         break;
     case SyncResult::Error:
+        Q_FALLTHROUGH();
     case SyncResult::SetupError:
     // FIXME: Use state-problem once we have an icon.
-    default:
         statusIcon = QStringLiteral("state-error");
     }
     if (sysTray) {
@@ -630,6 +633,11 @@ QString Theme::oauthClientSecret() const
     return QStringLiteral("UBntmLjC2yYCeHwsyj73Uwo9TAaecAetRwMw0xYcvNL9yRdLSUi0hUAHfvCHFeFh");
 }
 
+QString Theme::oauthLocalhost() const
+{
+    return QStringLiteral("http://localhost");
+}
+
 QPair<QString, QString> Theme::oauthOverrideAuthUrl() const
 {
     return {};
@@ -665,4 +673,9 @@ bool Theme::enableExperimentalFeatures() const
     return ConfigFile().showExperimentalOptions();
 }
 
+bool Theme::connectionValidatorClearCookies() const
+{
+    return false;
+}
+
 } // end namespace client
